# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable
from typing_extensions import Required, Annotated, TypedDict

from .._utils import PropertyInfo
from .criterion_param import CriterionParam
from .rollup_settings_param import RollupSettingsParam
from .evaluator_source_param import EvaluatorSourceParam

__all__ = ["EvaluatorCreateParams", "Evaluator"]


class EvaluatorCreateParams(TypedDict, total=False):
    account_id: str

    evaluator: Required[Evaluator]

    evaluator_id: Annotated[str, PropertyInfo(alias="evaluatorId")]


class Evaluator(TypedDict, total=False):
    commit_hash: Annotated[str, PropertyInfo(alias="commitHash")]

    criteria: Iterable[CriterionParam]

    default_dataset: Annotated[str, PropertyInfo(alias="defaultDataset")]

    description: str

    display_name: Annotated[str, PropertyInfo(alias="displayName")]

    entry_point: Annotated[str, PropertyInfo(alias="entryPoint")]

    multi_metrics: Annotated[bool, PropertyInfo(alias="multiMetrics")]
    """
    If true, the criteria will report multiple metric-score pairs Otherwise, each
    criteria will report the score assigned to the criteria name as metric.
    """

    requirements: str

    rollup_settings: Annotated[RollupSettingsParam, PropertyInfo(alias="rollupSettings")]
    """Strategy for metrics reports summary/rollup. e.g.

    {metric1: 1, metric2: 0.3}, rollup_settings could be criteria_weights: {metric1:
    0.5, metric2: 0.5}, then final score will be 0.5 _ 1 + 0.5 _ 0.3 = 0.65 If
    skip_rollup is true, the rollup step will be skipped since the criteria will
    also report the rollup score and metrics altogether.
    """

    source: EvaluatorSourceParam
    """Source information for the evaluator codebase."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .choice import Choice as Choice
from .status import Status as Status
from .log_probs import LogProbs as LogProbs
from .raw_output import RawOutput as RawOutput
from .usage_info import UsageInfo as UsageInfo
from .chat_message import ChatMessage as ChatMessage
from .wandb_config import WandbConfig as WandbConfig
from .new_log_probs import NewLogProbs as NewLogProbs
from .deployed_model import DeployedModel as DeployedModel
from .training_config import TrainingConfig as TrainingConfig
from .deployed_model_ref import DeployedModelRef as DeployedModelRef
from .chat_completion_tool import ChatCompletionTool as ChatCompletionTool
from .inference_parameters import InferenceParameters as InferenceParameters
from .new_log_probs_content import NewLogProbsContent as NewLogProbsContent
from .prompt_tokens_details import PromptTokensDetails as PromptTokensDetails
from .chat_completion_message_tool_call import ChatCompletionMessageToolCall as ChatCompletionMessageToolCall
from .new_log_probs_content_top_log_probs import NewLogProbsContentTopLogProbs as NewLogProbsContentTopLogProbs
from .chat_completion_message_tool_call_function import (
    ChatCompletionMessageToolCallFunction as ChatCompletionMessageToolCallFunction,
)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, Iterable

import httpx

from ..types import (
    evaluator_get_params,
    evaluator_list_params,
    evaluator_create_params,
    evaluator_update_params,
    evaluator_validate_upload_params,
    evaluator_get_upload_endpoint_params,
    evaluator_get_build_log_endpoint_params,
    evaluator_get_source_code_endpoint_params,
)
from .._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..pagination import SyncCursorEvaluators, AsyncCursorEvaluators
from .._base_client import AsyncPaginator, make_request_options
from ..types.criterion_param import CriterionParam
from ..types.rollup_settings_param import RollupSettingsParam
from ..types.evaluator_get_response import EvaluatorGetResponse
from ..types.evaluator_source_param import EvaluatorSourceParam
from ..types.evaluator_list_response import EvaluatorListResponse
from ..types.evaluator_create_response import EvaluatorCreateResponse
from ..types.evaluator_update_response import EvaluatorUpdateResponse
from ..types.evaluator_get_upload_endpoint_response import EvaluatorGetUploadEndpointResponse
from ..types.evaluator_get_build_log_endpoint_response import EvaluatorGetBuildLogEndpointResponse
from ..types.evaluator_get_source_code_endpoint_response import EvaluatorGetSourceCodeEndpointResponse

__all__ = ["EvaluatorsResource", "AsyncEvaluatorsResource"]


class EvaluatorsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> EvaluatorsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/fw-ai-external/python-sdk#accessing-raw-response-data-eg-headers
        """
        return EvaluatorsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> EvaluatorsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/fw-ai-external/python-sdk#with_streaming_response
        """
        return EvaluatorsResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        account_id: str | None = None,
        evaluator: evaluator_create_params.Evaluator,
        evaluator_id: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EvaluatorCreateResponse:
        """Creates a custom evaluator for scoring model outputs.

        Evaluators use the
        [Eval Protocol](https://evalprotocol.io) to define test cases, run model
        inference, and score responses. They are used with evaluation jobs and
        Reinforcement Fine-Tuning (RFT).

        ## Source Code Requirements

        Your project should contain:

        - `requirements.txt` - Python dependencies for your evaluator
        - `test_*.py` - Pytest test file(s) with
          [`@evaluation_test`](https://evalprotocol.io/reference/evaluation-test)
          decorated functions
        - Any additional code/modules your evaluator needs

        ## Workflow

        **Recommended:** Use the
        [`ep upload`](https://evalprotocol.io/reference/cli#ep-upload) CLI command to
        handle all these steps automatically.

        If using the API directly:

        1. Call this endpoint to create the evaluator resource
        2. Package your source directory as a `.tar.gz` (respecting `.gitignore`)
        3. Call
           [Get Evaluator Upload Endpoint](/api-reference/get-evaluator-upload-endpoint)
           to get a signed upload URL
        4. `PUT` the tar.gz file to the signed URL
        5. Call [Validate Evaluator Upload](/api-reference/validate-evaluator-upload) to
           trigger server-side validation
        6. Poll [Get Evaluator](/api-reference/get-evaluator) until ready

        Once active, reference the evaluator in
        [Create Evaluation Job](/api-reference/create-evaluation-job) or
        [Create Reinforcement Fine-tuning Job](/api-reference/create-reinforcement-fine-tuning-job).

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if account_id is None:
            account_id = self._client._get_account_id_path_param()
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return self._post(
            f"/v1/accounts/{account_id}/evaluatorsV2"
            if self._client._base_url_overridden
            else f"https://api.fireworks.ai/v1/accounts/{account_id}/evaluatorsV2",
            body=maybe_transform(
                {
                    "evaluator": evaluator,
                    "evaluator_id": evaluator_id,
                },
                evaluator_create_params.EvaluatorCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EvaluatorCreateResponse,
        )

    def update(
        self,
        evaluator_id: str,
        *,
        account_id: str | None = None,
        prepare_code_upload: bool | Omit = omit,
        commit_hash: str | Omit = omit,
        criteria: Iterable[CriterionParam] | Omit = omit,
        default_dataset: str | Omit = omit,
        description: str | Omit = omit,
        display_name: str | Omit = omit,
        entry_point: str | Omit = omit,
        multi_metrics: bool | Omit = omit,
        requirements: str | Omit = omit,
        rollup_settings: RollupSettingsParam | Omit = omit,
        source: EvaluatorSourceParam | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EvaluatorUpdateResponse:
        """
        Updates evaluator metadata (display_name, description, default_dataset).
        Changing `requirements` or `entry_point` triggers a rebuild. To upload new
        source code, set `prepare_code_upload: true` then follow the upload flow.

        Args:
          prepare_code_upload: If true, prepare a new code upload/build attempt by transitioning the evaluator
              to BUILDING state. Can be used without update_mask.

          multi_metrics: If true, the criteria will report multiple metric-score pairs Otherwise, each
              criteria will report the score assigned to the criteria name as metric.

          rollup_settings: Strategy for metrics reports summary/rollup. e.g. {metric1: 1, metric2: 0.3},
              rollup_settings could be criteria_weights: {metric1: 0.5, metric2: 0.5}, then
              final score will be 0.5 _ 1 + 0.5 _ 0.3 = 0.65 If skip_rollup is true, the
              rollup step will be skipped since the criteria will also report the rollup score
              and metrics altogether.

          source: Source information for the evaluator codebase.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if account_id is None:
            account_id = self._client._get_account_id_path_param()
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not evaluator_id:
            raise ValueError(f"Expected a non-empty value for `evaluator_id` but received {evaluator_id!r}")
        return self._patch(
            f"/v1/accounts/{account_id}/evaluators/{evaluator_id}"
            if self._client._base_url_overridden
            else f"https://api.fireworks.ai/v1/accounts/{account_id}/evaluators/{evaluator_id}",
            body=maybe_transform(
                {
                    "commit_hash": commit_hash,
                    "criteria": criteria,
                    "default_dataset": default_dataset,
                    "description": description,
                    "display_name": display_name,
                    "entry_point": entry_point,
                    "multi_metrics": multi_metrics,
                    "requirements": requirements,
                    "rollup_settings": rollup_settings,
                    "source": source,
                },
                evaluator_update_params.EvaluatorUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {"prepare_code_upload": prepare_code_upload}, evaluator_update_params.EvaluatorUpdateParams
                ),
            ),
            cast_to=EvaluatorUpdateResponse,
        )

    def list(
        self,
        *,
        account_id: str | None = None,
        filter: str | Omit = omit,
        order_by: str | Omit = omit,
        page_size: int | Omit = omit,
        page_token: str | Omit = omit,
        read_mask: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SyncCursorEvaluators[EvaluatorListResponse]:
        """
        Lists all evaluators for an account with pagination support.

        Args:
          read_mask: The fields to be returned in the response. If empty or "\\**", all fields will be
              returned.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if account_id is None:
            account_id = self._client._get_account_id_path_param()
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return self._get_api_list(
            f"/v1/accounts/{account_id}/evaluators"
            if self._client._base_url_overridden
            else f"https://api.fireworks.ai/v1/accounts/{account_id}/evaluators",
            page=SyncCursorEvaluators[EvaluatorListResponse],
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "filter": filter,
                        "order_by": order_by,
                        "page_size": page_size,
                        "page_token": page_token,
                        "read_mask": read_mask,
                    },
                    evaluator_list_params.EvaluatorListParams,
                ),
            ),
            model=EvaluatorListResponse,
        )

    def delete(
        self,
        evaluator_id: str,
        *,
        account_id: str | None = None,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> object:
        """
        Deletes an evaluator and its associated versions and build artifacts.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if account_id is None:
            account_id = self._client._get_account_id_path_param()
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not evaluator_id:
            raise ValueError(f"Expected a non-empty value for `evaluator_id` but received {evaluator_id!r}")
        return self._delete(
            f"/v1/accounts/{account_id}/evaluators/{evaluator_id}"
            if self._client._base_url_overridden
            else f"https://api.fireworks.ai/v1/accounts/{account_id}/evaluators/{evaluator_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    def get(
        self,
        evaluator_id: str,
        *,
        account_id: str | None = None,
        read_mask: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EvaluatorGetResponse:
        """Retrieves an evaluator by name.

        Use this to monitor build progress after
        creation (**step 6** in the [Create Evaluator](/api-reference/create-evaluator)
        workflow).

        Possible states:

        - `BUILDING` - Environment is being prepared
        - `ACTIVE` - Evaluator is ready to use
        - `BUILD_FAILED` - Check build logs via
          [Get Evaluator Build Log Endpoint](/api-reference/get-evaluator-build-log-endpoint)

        Args:
          read_mask: The fields to be returned in the response. If empty or "\\**", all fields will be
              returned.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if account_id is None:
            account_id = self._client._get_account_id_path_param()
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not evaluator_id:
            raise ValueError(f"Expected a non-empty value for `evaluator_id` but received {evaluator_id!r}")
        return self._get(
            f"/v1/accounts/{account_id}/evaluators/{evaluator_id}"
            if self._client._base_url_overridden
            else f"https://api.fireworks.ai/v1/accounts/{account_id}/evaluators/{evaluator_id}",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform({"read_mask": read_mask}, evaluator_get_params.EvaluatorGetParams),
            ),
            cast_to=EvaluatorGetResponse,
        )

    def get_build_log_endpoint(
        self,
        evaluator_id: str,
        *,
        account_id: str | None = None,
        read_mask: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EvaluatorGetBuildLogEndpointResponse:
        """Returns a signed URL to download the evaluator's build logs.

        Useful for
        debugging `BUILD_FAILED` state.

        Args:
          read_mask: The fields to be returned in the response. If empty or "\\**", all fields will be
              returned.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if account_id is None:
            account_id = self._client._get_account_id_path_param()
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not evaluator_id:
            raise ValueError(f"Expected a non-empty value for `evaluator_id` but received {evaluator_id!r}")
        return self._get(
            f"/v1/accounts/{account_id}/evaluators/{evaluator_id}:getBuildLogEndpoint"
            if self._client._base_url_overridden
            else f"https://api.fireworks.ai/v1/accounts/{account_id}/evaluators/{evaluator_id}:getBuildLogEndpoint",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {"read_mask": read_mask}, evaluator_get_build_log_endpoint_params.EvaluatorGetBuildLogEndpointParams
                ),
            ),
            cast_to=EvaluatorGetBuildLogEndpointResponse,
        )

    def get_source_code_endpoint(
        self,
        evaluator_id: str,
        *,
        account_id: str | None = None,
        read_mask: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EvaluatorGetSourceCodeEndpointResponse:
        """Returns a signed URL to download the evaluator's source code archive.

        Useful for
        debugging or reviewing the uploaded code.

        Args:
          read_mask: The fields to be returned in the response. If empty or "\\**", all fields will be
              returned.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if account_id is None:
            account_id = self._client._get_account_id_path_param()
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not evaluator_id:
            raise ValueError(f"Expected a non-empty value for `evaluator_id` but received {evaluator_id!r}")
        return self._get(
            f"/v1/accounts/{account_id}/evaluators/{evaluator_id}:getSourceCodeSignedUrl"
            if self._client._base_url_overridden
            else f"https://api.fireworks.ai/v1/accounts/{account_id}/evaluators/{evaluator_id}:getSourceCodeSignedUrl",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {"read_mask": read_mask},
                    evaluator_get_source_code_endpoint_params.EvaluatorGetSourceCodeEndpointParams,
                ),
            ),
            cast_to=EvaluatorGetSourceCodeEndpointResponse,
        )

    def get_upload_endpoint(
        self,
        evaluator_id: str,
        *,
        account_id: str | None = None,
        filename_to_size: Dict[str, str],
        read_mask: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EvaluatorGetUploadEndpointResponse:
        """
        Returns signed URLs for uploading evaluator source code (**step 3** in the
        [Create Evaluator](/api-reference/create-evaluator) workflow). After receiving
        the signed URL, upload your `.tar.gz` archive using HTTP `PUT` with
        `Content-Type: application/octet-stream` header.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if account_id is None:
            account_id = self._client._get_account_id_path_param()
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not evaluator_id:
            raise ValueError(f"Expected a non-empty value for `evaluator_id` but received {evaluator_id!r}")
        return self._post(
            f"/v1/accounts/{account_id}/evaluators/{evaluator_id}:getUploadEndpoint"
            if self._client._base_url_overridden
            else f"https://api.fireworks.ai/v1/accounts/{account_id}/evaluators/{evaluator_id}:getUploadEndpoint",
            body=maybe_transform(
                {
                    "filename_to_size": filename_to_size,
                    "read_mask": read_mask,
                },
                evaluator_get_upload_endpoint_params.EvaluatorGetUploadEndpointParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EvaluatorGetUploadEndpointResponse,
        )

    def validate_upload(
        self,
        evaluator_id: str,
        *,
        account_id: str | None = None,
        body: object,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> object:
        """
        Triggers server-side validation of the uploaded source code (**step 5** in the
        [Create Evaluator](/api-reference/create-evaluator) workflow). The server
        extracts and processes the archive, then builds the evaluator environment. Poll
        [Get Evaluator](/api-reference/get-evaluator) to monitor progress.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if account_id is None:
            account_id = self._client._get_account_id_path_param()
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not evaluator_id:
            raise ValueError(f"Expected a non-empty value for `evaluator_id` but received {evaluator_id!r}")
        return self._post(
            f"/v1/accounts/{account_id}/evaluators/{evaluator_id}:validateUpload"
            if self._client._base_url_overridden
            else f"https://api.fireworks.ai/v1/accounts/{account_id}/evaluators/{evaluator_id}:validateUpload",
            body=maybe_transform(body, evaluator_validate_upload_params.EvaluatorValidateUploadParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )


class AsyncEvaluatorsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncEvaluatorsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/fw-ai-external/python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncEvaluatorsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncEvaluatorsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/fw-ai-external/python-sdk#with_streaming_response
        """
        return AsyncEvaluatorsResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        account_id: str | None = None,
        evaluator: evaluator_create_params.Evaluator,
        evaluator_id: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EvaluatorCreateResponse:
        """Creates a custom evaluator for scoring model outputs.

        Evaluators use the
        [Eval Protocol](https://evalprotocol.io) to define test cases, run model
        inference, and score responses. They are used with evaluation jobs and
        Reinforcement Fine-Tuning (RFT).

        ## Source Code Requirements

        Your project should contain:

        - `requirements.txt` - Python dependencies for your evaluator
        - `test_*.py` - Pytest test file(s) with
          [`@evaluation_test`](https://evalprotocol.io/reference/evaluation-test)
          decorated functions
        - Any additional code/modules your evaluator needs

        ## Workflow

        **Recommended:** Use the
        [`ep upload`](https://evalprotocol.io/reference/cli#ep-upload) CLI command to
        handle all these steps automatically.

        If using the API directly:

        1. Call this endpoint to create the evaluator resource
        2. Package your source directory as a `.tar.gz` (respecting `.gitignore`)
        3. Call
           [Get Evaluator Upload Endpoint](/api-reference/get-evaluator-upload-endpoint)
           to get a signed upload URL
        4. `PUT` the tar.gz file to the signed URL
        5. Call [Validate Evaluator Upload](/api-reference/validate-evaluator-upload) to
           trigger server-side validation
        6. Poll [Get Evaluator](/api-reference/get-evaluator) until ready

        Once active, reference the evaluator in
        [Create Evaluation Job](/api-reference/create-evaluation-job) or
        [Create Reinforcement Fine-tuning Job](/api-reference/create-reinforcement-fine-tuning-job).

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if account_id is None:
            account_id = self._client._get_account_id_path_param()
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return await self._post(
            f"/v1/accounts/{account_id}/evaluatorsV2"
            if self._client._base_url_overridden
            else f"https://api.fireworks.ai/v1/accounts/{account_id}/evaluatorsV2",
            body=await async_maybe_transform(
                {
                    "evaluator": evaluator,
                    "evaluator_id": evaluator_id,
                },
                evaluator_create_params.EvaluatorCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EvaluatorCreateResponse,
        )

    async def update(
        self,
        evaluator_id: str,
        *,
        account_id: str | None = None,
        prepare_code_upload: bool | Omit = omit,
        commit_hash: str | Omit = omit,
        criteria: Iterable[CriterionParam] | Omit = omit,
        default_dataset: str | Omit = omit,
        description: str | Omit = omit,
        display_name: str | Omit = omit,
        entry_point: str | Omit = omit,
        multi_metrics: bool | Omit = omit,
        requirements: str | Omit = omit,
        rollup_settings: RollupSettingsParam | Omit = omit,
        source: EvaluatorSourceParam | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EvaluatorUpdateResponse:
        """
        Updates evaluator metadata (display_name, description, default_dataset).
        Changing `requirements` or `entry_point` triggers a rebuild. To upload new
        source code, set `prepare_code_upload: true` then follow the upload flow.

        Args:
          prepare_code_upload: If true, prepare a new code upload/build attempt by transitioning the evaluator
              to BUILDING state. Can be used without update_mask.

          multi_metrics: If true, the criteria will report multiple metric-score pairs Otherwise, each
              criteria will report the score assigned to the criteria name as metric.

          rollup_settings: Strategy for metrics reports summary/rollup. e.g. {metric1: 1, metric2: 0.3},
              rollup_settings could be criteria_weights: {metric1: 0.5, metric2: 0.5}, then
              final score will be 0.5 _ 1 + 0.5 _ 0.3 = 0.65 If skip_rollup is true, the
              rollup step will be skipped since the criteria will also report the rollup score
              and metrics altogether.

          source: Source information for the evaluator codebase.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if account_id is None:
            account_id = self._client._get_account_id_path_param()
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not evaluator_id:
            raise ValueError(f"Expected a non-empty value for `evaluator_id` but received {evaluator_id!r}")
        return await self._patch(
            f"/v1/accounts/{account_id}/evaluators/{evaluator_id}"
            if self._client._base_url_overridden
            else f"https://api.fireworks.ai/v1/accounts/{account_id}/evaluators/{evaluator_id}",
            body=await async_maybe_transform(
                {
                    "commit_hash": commit_hash,
                    "criteria": criteria,
                    "default_dataset": default_dataset,
                    "description": description,
                    "display_name": display_name,
                    "entry_point": entry_point,
                    "multi_metrics": multi_metrics,
                    "requirements": requirements,
                    "rollup_settings": rollup_settings,
                    "source": source,
                },
                evaluator_update_params.EvaluatorUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {"prepare_code_upload": prepare_code_upload}, evaluator_update_params.EvaluatorUpdateParams
                ),
            ),
            cast_to=EvaluatorUpdateResponse,
        )

    def list(
        self,
        *,
        account_id: str | None = None,
        filter: str | Omit = omit,
        order_by: str | Omit = omit,
        page_size: int | Omit = omit,
        page_token: str | Omit = omit,
        read_mask: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AsyncPaginator[EvaluatorListResponse, AsyncCursorEvaluators[EvaluatorListResponse]]:
        """
        Lists all evaluators for an account with pagination support.

        Args:
          read_mask: The fields to be returned in the response. If empty or "\\**", all fields will be
              returned.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if account_id is None:
            account_id = self._client._get_account_id_path_param()
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return self._get_api_list(
            f"/v1/accounts/{account_id}/evaluators"
            if self._client._base_url_overridden
            else f"https://api.fireworks.ai/v1/accounts/{account_id}/evaluators",
            page=AsyncCursorEvaluators[EvaluatorListResponse],
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "filter": filter,
                        "order_by": order_by,
                        "page_size": page_size,
                        "page_token": page_token,
                        "read_mask": read_mask,
                    },
                    evaluator_list_params.EvaluatorListParams,
                ),
            ),
            model=EvaluatorListResponse,
        )

    async def delete(
        self,
        evaluator_id: str,
        *,
        account_id: str | None = None,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> object:
        """
        Deletes an evaluator and its associated versions and build artifacts.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if account_id is None:
            account_id = self._client._get_account_id_path_param()
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not evaluator_id:
            raise ValueError(f"Expected a non-empty value for `evaluator_id` but received {evaluator_id!r}")
        return await self._delete(
            f"/v1/accounts/{account_id}/evaluators/{evaluator_id}"
            if self._client._base_url_overridden
            else f"https://api.fireworks.ai/v1/accounts/{account_id}/evaluators/{evaluator_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    async def get(
        self,
        evaluator_id: str,
        *,
        account_id: str | None = None,
        read_mask: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EvaluatorGetResponse:
        """Retrieves an evaluator by name.

        Use this to monitor build progress after
        creation (**step 6** in the [Create Evaluator](/api-reference/create-evaluator)
        workflow).

        Possible states:

        - `BUILDING` - Environment is being prepared
        - `ACTIVE` - Evaluator is ready to use
        - `BUILD_FAILED` - Check build logs via
          [Get Evaluator Build Log Endpoint](/api-reference/get-evaluator-build-log-endpoint)

        Args:
          read_mask: The fields to be returned in the response. If empty or "\\**", all fields will be
              returned.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if account_id is None:
            account_id = self._client._get_account_id_path_param()
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not evaluator_id:
            raise ValueError(f"Expected a non-empty value for `evaluator_id` but received {evaluator_id!r}")
        return await self._get(
            f"/v1/accounts/{account_id}/evaluators/{evaluator_id}"
            if self._client._base_url_overridden
            else f"https://api.fireworks.ai/v1/accounts/{account_id}/evaluators/{evaluator_id}",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform({"read_mask": read_mask}, evaluator_get_params.EvaluatorGetParams),
            ),
            cast_to=EvaluatorGetResponse,
        )

    async def get_build_log_endpoint(
        self,
        evaluator_id: str,
        *,
        account_id: str | None = None,
        read_mask: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EvaluatorGetBuildLogEndpointResponse:
        """Returns a signed URL to download the evaluator's build logs.

        Useful for
        debugging `BUILD_FAILED` state.

        Args:
          read_mask: The fields to be returned in the response. If empty or "\\**", all fields will be
              returned.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if account_id is None:
            account_id = self._client._get_account_id_path_param()
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not evaluator_id:
            raise ValueError(f"Expected a non-empty value for `evaluator_id` but received {evaluator_id!r}")
        return await self._get(
            f"/v1/accounts/{account_id}/evaluators/{evaluator_id}:getBuildLogEndpoint"
            if self._client._base_url_overridden
            else f"https://api.fireworks.ai/v1/accounts/{account_id}/evaluators/{evaluator_id}:getBuildLogEndpoint",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {"read_mask": read_mask}, evaluator_get_build_log_endpoint_params.EvaluatorGetBuildLogEndpointParams
                ),
            ),
            cast_to=EvaluatorGetBuildLogEndpointResponse,
        )

    async def get_source_code_endpoint(
        self,
        evaluator_id: str,
        *,
        account_id: str | None = None,
        read_mask: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EvaluatorGetSourceCodeEndpointResponse:
        """Returns a signed URL to download the evaluator's source code archive.

        Useful for
        debugging or reviewing the uploaded code.

        Args:
          read_mask: The fields to be returned in the response. If empty or "\\**", all fields will be
              returned.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if account_id is None:
            account_id = self._client._get_account_id_path_param()
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not evaluator_id:
            raise ValueError(f"Expected a non-empty value for `evaluator_id` but received {evaluator_id!r}")
        return await self._get(
            f"/v1/accounts/{account_id}/evaluators/{evaluator_id}:getSourceCodeSignedUrl"
            if self._client._base_url_overridden
            else f"https://api.fireworks.ai/v1/accounts/{account_id}/evaluators/{evaluator_id}:getSourceCodeSignedUrl",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {"read_mask": read_mask},
                    evaluator_get_source_code_endpoint_params.EvaluatorGetSourceCodeEndpointParams,
                ),
            ),
            cast_to=EvaluatorGetSourceCodeEndpointResponse,
        )

    async def get_upload_endpoint(
        self,
        evaluator_id: str,
        *,
        account_id: str | None = None,
        filename_to_size: Dict[str, str],
        read_mask: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EvaluatorGetUploadEndpointResponse:
        """
        Returns signed URLs for uploading evaluator source code (**step 3** in the
        [Create Evaluator](/api-reference/create-evaluator) workflow). After receiving
        the signed URL, upload your `.tar.gz` archive using HTTP `PUT` with
        `Content-Type: application/octet-stream` header.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if account_id is None:
            account_id = self._client._get_account_id_path_param()
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not evaluator_id:
            raise ValueError(f"Expected a non-empty value for `evaluator_id` but received {evaluator_id!r}")
        return await self._post(
            f"/v1/accounts/{account_id}/evaluators/{evaluator_id}:getUploadEndpoint"
            if self._client._base_url_overridden
            else f"https://api.fireworks.ai/v1/accounts/{account_id}/evaluators/{evaluator_id}:getUploadEndpoint",
            body=await async_maybe_transform(
                {
                    "filename_to_size": filename_to_size,
                    "read_mask": read_mask,
                },
                evaluator_get_upload_endpoint_params.EvaluatorGetUploadEndpointParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EvaluatorGetUploadEndpointResponse,
        )

    async def validate_upload(
        self,
        evaluator_id: str,
        *,
        account_id: str | None = None,
        body: object,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> object:
        """
        Triggers server-side validation of the uploaded source code (**step 5** in the
        [Create Evaluator](/api-reference/create-evaluator) workflow). The server
        extracts and processes the archive, then builds the evaluator environment. Poll
        [Get Evaluator](/api-reference/get-evaluator) to monitor progress.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if account_id is None:
            account_id = self._client._get_account_id_path_param()
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not evaluator_id:
            raise ValueError(f"Expected a non-empty value for `evaluator_id` but received {evaluator_id!r}")
        return await self._post(
            f"/v1/accounts/{account_id}/evaluators/{evaluator_id}:validateUpload"
            if self._client._base_url_overridden
            else f"https://api.fireworks.ai/v1/accounts/{account_id}/evaluators/{evaluator_id}:validateUpload",
            body=await async_maybe_transform(body, evaluator_validate_upload_params.EvaluatorValidateUploadParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )


class EvaluatorsResourceWithRawResponse:
    def __init__(self, evaluators: EvaluatorsResource) -> None:
        self._evaluators = evaluators

        self.create = to_raw_response_wrapper(
            evaluators.create,
        )
        self.update = to_raw_response_wrapper(
            evaluators.update,
        )
        self.list = to_raw_response_wrapper(
            evaluators.list,
        )
        self.delete = to_raw_response_wrapper(
            evaluators.delete,
        )
        self.get = to_raw_response_wrapper(
            evaluators.get,
        )
        self.get_build_log_endpoint = to_raw_response_wrapper(
            evaluators.get_build_log_endpoint,
        )
        self.get_source_code_endpoint = to_raw_response_wrapper(
            evaluators.get_source_code_endpoint,
        )
        self.get_upload_endpoint = to_raw_response_wrapper(
            evaluators.get_upload_endpoint,
        )
        self.validate_upload = to_raw_response_wrapper(
            evaluators.validate_upload,
        )


class AsyncEvaluatorsResourceWithRawResponse:
    def __init__(self, evaluators: AsyncEvaluatorsResource) -> None:
        self._evaluators = evaluators

        self.create = async_to_raw_response_wrapper(
            evaluators.create,
        )
        self.update = async_to_raw_response_wrapper(
            evaluators.update,
        )
        self.list = async_to_raw_response_wrapper(
            evaluators.list,
        )
        self.delete = async_to_raw_response_wrapper(
            evaluators.delete,
        )
        self.get = async_to_raw_response_wrapper(
            evaluators.get,
        )
        self.get_build_log_endpoint = async_to_raw_response_wrapper(
            evaluators.get_build_log_endpoint,
        )
        self.get_source_code_endpoint = async_to_raw_response_wrapper(
            evaluators.get_source_code_endpoint,
        )
        self.get_upload_endpoint = async_to_raw_response_wrapper(
            evaluators.get_upload_endpoint,
        )
        self.validate_upload = async_to_raw_response_wrapper(
            evaluators.validate_upload,
        )


class EvaluatorsResourceWithStreamingResponse:
    def __init__(self, evaluators: EvaluatorsResource) -> None:
        self._evaluators = evaluators

        self.create = to_streamed_response_wrapper(
            evaluators.create,
        )
        self.update = to_streamed_response_wrapper(
            evaluators.update,
        )
        self.list = to_streamed_response_wrapper(
            evaluators.list,
        )
        self.delete = to_streamed_response_wrapper(
            evaluators.delete,
        )
        self.get = to_streamed_response_wrapper(
            evaluators.get,
        )
        self.get_build_log_endpoint = to_streamed_response_wrapper(
            evaluators.get_build_log_endpoint,
        )
        self.get_source_code_endpoint = to_streamed_response_wrapper(
            evaluators.get_source_code_endpoint,
        )
        self.get_upload_endpoint = to_streamed_response_wrapper(
            evaluators.get_upload_endpoint,
        )
        self.validate_upload = to_streamed_response_wrapper(
            evaluators.validate_upload,
        )


class AsyncEvaluatorsResourceWithStreamingResponse:
    def __init__(self, evaluators: AsyncEvaluatorsResource) -> None:
        self._evaluators = evaluators

        self.create = async_to_streamed_response_wrapper(
            evaluators.create,
        )
        self.update = async_to_streamed_response_wrapper(
            evaluators.update,
        )
        self.list = async_to_streamed_response_wrapper(
            evaluators.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            evaluators.delete,
        )
        self.get = async_to_streamed_response_wrapper(
            evaluators.get,
        )
        self.get_build_log_endpoint = async_to_streamed_response_wrapper(
            evaluators.get_build_log_endpoint,
        )
        self.get_source_code_endpoint = async_to_streamed_response_wrapper(
            evaluators.get_source_code_endpoint,
        )
        self.get_upload_endpoint = async_to_streamed_response_wrapper(
            evaluators.get_upload_endpoint,
        )
        self.validate_upload = async_to_streamed_response_wrapper(
            evaluators.validate_upload,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Annotated, TypedDict

from .._utils import PropertyInfo
from .code_snippets_param import CodeSnippetsParam

__all__ = ["CriterionParam"]


class CriterionParam(TypedDict, total=False):
    code_snippets: Annotated[CodeSnippetsParam, PropertyInfo(alias="codeSnippets")]

    description: str

    name: str

    type: Literal["TYPE_UNSPECIFIED", "CODE_SNIPPETS"]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict
from typing_extensions import Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["CodeSnippetsParam"]


class CodeSnippetsParam(TypedDict, total=False):
    entry_file: Annotated[str, PropertyInfo(alias="entryFile")]

    entry_func: Annotated[str, PropertyInfo(alias="entryFunc")]

    file_contents: Annotated[Dict[str, str], PropertyInfo(alias="fileContents")]

    language: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .._models import BaseModel
from .code_snippets import CodeSnippets

__all__ = ["Criterion"]


class Criterion(BaseModel):
    code_snippets: Optional[CodeSnippets] = FieldInfo(alias="codeSnippets", default=None)

    description: Optional[str] = None

    name: Optional[str] = None

    type: Optional[Literal["TYPE_UNSPECIFIED", "CODE_SNIPPETS"]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict
from typing_extensions import Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["EvaluatorGetUploadEndpointParams"]


class EvaluatorGetUploadEndpointParams(TypedDict, total=False):
    account_id: str

    filename_to_size: Required[Annotated[Dict[str, str], PropertyInfo(alias="filenameToSize")]]

    read_mask: Annotated[str, PropertyInfo(alias="readMask")]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict
from typing_extensions import Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["RollupSettingsParam"]


class RollupSettingsParam(TypedDict, total=False):
    criteria_weights: Annotated[Dict[str, float], PropertyInfo(alias="criteriaWeights")]

    python_code: Annotated[str, PropertyInfo(alias="pythonCode")]

    skip_rollup: Annotated[bool, PropertyInfo(alias="skipRollup")]

    success_threshold: Annotated[float, PropertyInfo(alias="successThreshold")]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .._models import BaseModel
from .shared.status import Status
from .shared.wandb_config import WandbConfig
from .shared.training_config import TrainingConfig

__all__ = ["ReinforcementFineTuningStep"]


class ReinforcementFineTuningStep(BaseModel):
    completed_time: Optional[datetime] = FieldInfo(alias="completedTime", default=None)

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """The email address of the user who initiated this fine-tuning job."""

    create_time: Optional[datetime] = FieldInfo(alias="createTime", default=None)

    dataset: Optional[str] = None
    """The name of the dataset used for training."""

    display_name: Optional[str] = FieldInfo(alias="displayName", default=None)

    eval_auto_carveout: Optional[bool] = FieldInfo(alias="evalAutoCarveout", default=None)
    """Whether to auto-carve the dataset for eval."""

    evaluation_dataset: Optional[str] = FieldInfo(alias="evaluationDataset", default=None)
    """The name of a separate dataset to use for evaluation."""

    keep_alive: Optional[bool] = FieldInfo(alias="keepAlive", default=None)

    name: Optional[str] = None

    reward_weights: Optional[List[str]] = FieldInfo(alias="rewardWeights", default=None)
    """
    A list of reward metrics to use for training in format of
    "<reward_name>=<weight>".
    """

    rollout_deployment_name: Optional[str] = FieldInfo(alias="rolloutDeploymentName", default=None)
    """Rollout deployment name associated with this RLOR trainer job. This is optional.

    If not set, trainer will not trigger weight sync to rollout engine.
    """

    state: Optional[
        Literal[
            "JOB_STATE_UNSPECIFIED",
            "JOB_STATE_CREATING",
            "JOB_STATE_RUNNING",
            "JOB_STATE_COMPLETED",
            "JOB_STATE_FAILED",
            "JOB_STATE_CANCELLED",
            "JOB_STATE_DELETING",
            "JOB_STATE_WRITING_RESULTS",
            "JOB_STATE_VALIDATING",
            "JOB_STATE_DELETING_CLEANING_UP",
            "JOB_STATE_PENDING",
            "JOB_STATE_EXPIRED",
            "JOB_STATE_RE_QUEUEING",
            "JOB_STATE_CREATING_INPUT_DATASET",
            "JOB_STATE_IDLE",
            "JOB_STATE_CANCELLING",
            "JOB_STATE_EARLY_STOPPED",
            "JOB_STATE_PAUSED",
        ]
    ] = None
    """JobState represents the state an asynchronous job can be in.

    - JOB_STATE_PAUSED: Job is paused, typically due to account suspension or manual
      intervention.
    """

    status: Optional[Status] = None

    training_config: Optional[TrainingConfig] = FieldInfo(alias="trainingConfig", default=None)
    """Common training configurations."""

    wandb_config: Optional[WandbConfig] = FieldInfo(alias="wandbConfig", default=None)
    """The Weights & Biases team/user account for logging training progress."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from fireworks import Fireworks, AsyncFireworks
from tests.utils import assert_matches_type
from fireworks.types import (
    Dataset,
    DatasetUploadResponse,
    DatasetGetUploadEndpointResponse,
    DatasetGetDownloadEndpointResponse,
)
from fireworks.pagination import SyncCursorDatasets, AsyncCursorDatasets

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestDatasets:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_create(self, client: Fireworks) -> None:
        dataset = client.datasets.create(
            account_id="account_id",
            dataset={},
            dataset_id="datasetId",
        )
        assert_matches_type(Dataset, dataset, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_create_with_all_params(self, client: Fireworks) -> None:
        dataset = client.datasets.create(
            account_id="account_id",
            dataset={
                "display_name": "displayName",
                "eval_protocol": {},
                "evaluation_result": {"evaluation_job_id": "evaluationJobId"},
                "example_count": "exampleCount",
                "external_url": "externalUrl",
                "format": "FORMAT_UNSPECIFIED",
                "source_job_name": "sourceJobName",
                "splitted": {"source_dataset_id": "sourceDatasetId"},
                "transformed": {
                    "source_dataset_id": "sourceDatasetId",
                    "filter": "filter",
                    "original_format": "FORMAT_UNSPECIFIED",
                },
                "user_uploaded": {},
            },
            dataset_id="datasetId",
            filter="filter",
            source_dataset_id="sourceDatasetId",
        )
        assert_matches_type(Dataset, dataset, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_create(self, client: Fireworks) -> None:
        response = client.datasets.with_raw_response.create(
            account_id="account_id",
            dataset={},
            dataset_id="datasetId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        dataset = response.parse()
        assert_matches_type(Dataset, dataset, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_create(self, client: Fireworks) -> None:
        with client.datasets.with_streaming_response.create(
            account_id="account_id",
            dataset={},
            dataset_id="datasetId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            dataset = response.parse()
            assert_matches_type(Dataset, dataset, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_create(self, client: Fireworks) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `account_id` but received ''"):
            client.datasets.with_raw_response.create(
                account_id="",
                dataset={},
                dataset_id="datasetId",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_update(self, client: Fireworks) -> None:
        dataset = client.datasets.update(
            dataset_id="dataset_id",
            account_id="account_id",
        )
        assert_matches_type(Dataset, dataset, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_update_with_all_params(self, client: Fireworks) -> None:
        dataset = client.datasets.update(
            dataset_id="dataset_id",
            account_id="account_id",
            display_name="displayName",
            eval_protocol={},
            evaluation_result={"evaluation_job_id": "evaluationJobId"},
            example_count="exampleCount",
            external_url="externalUrl",
            format="FORMAT_UNSPECIFIED",
            source_job_name="sourceJobName",
            splitted={"source_dataset_id": "sourceDatasetId"},
            transformed={
                "source_dataset_id": "sourceDatasetId",
                "filter": "filter",
                "original_format": "FORMAT_UNSPECIFIED",
            },
            user_uploaded={},
        )
        assert_matches_type(Dataset, dataset, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_update(self, client: Fireworks) -> None:
        response = client.datasets.with_raw_response.update(
            dataset_id="dataset_id",
            account_id="account_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        dataset = response.parse()
        assert_matches_type(Dataset, dataset, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_update(self, client: Fireworks) -> None:
        with client.datasets.with_streaming_response.update(
            dataset_id="dataset_id",
            account_id="account_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            dataset = response.parse()
            assert_matches_type(Dataset, dataset, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_update(self, client: Fireworks) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `account_id` but received ''"):
            client.datasets.with_raw_response.update(
                dataset_id="dataset_id",
                account_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `dataset_id` but received ''"):
            client.datasets.with_raw_response.update(
                dataset_id="",
                account_id="account_id",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list(self, client: Fireworks) -> None:
        dataset = client.datasets.list(
            account_id="account_id",
        )
        assert_matches_type(SyncCursorDatasets[Dataset], dataset, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list_with_all_params(self, client: Fireworks) -> None:
        dataset = client.datasets.list(
            account_id="account_id",
            filter="filter",
            order_by="orderBy",
            page_size=0,
            page_token="pageToken",
            read_mask="readMask",
        )
        assert_matches_type(SyncCursorDatasets[Dataset], dataset, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_list(self, client: Fireworks) -> None:
        response = client.datasets.with_raw_response.list(
            account_id="account_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        dataset = response.parse()
        assert_matches_type(SyncCursorDatasets[Dataset], dataset, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_list(self, client: Fireworks) -> None:
        with client.datasets.with_streaming_response.list(
            account_id="account_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            dataset = response.parse()
            assert_matches_type(SyncCursorDatasets[Dataset], dataset, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_list(self, client: Fireworks) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `account_id` but received ''"):
            client.datasets.with_raw_response.list(
                account_id="",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_delete(self, client: Fireworks) -> None:
        dataset = client.datasets.delete(
            dataset_id="dataset_id",
            account_id="account_id",
        )
        assert_matches_type(object, dataset, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_delete(self, client: Fireworks) -> None:
        response = client.datasets.with_raw_response.delete(
            dataset_id="dataset_id",
            account_id="account_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        dataset = response.parse()
        assert_matches_type(object, dataset, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_delete(self, client: Fireworks) -> None:
        with client.datasets.with_streaming_response.delete(
            dataset_id="dataset_id",
            account_id="account_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            dataset = response.parse()
            assert_matches_type(object, dataset, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_delete(self, client: Fireworks) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `account_id` but received ''"):
            client.datasets.with_raw_response.delete(
                dataset_id="dataset_id",
                account_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `dataset_id` but received ''"):
            client.datasets.with_raw_response.delete(
                dataset_id="",
                account_id="account_id",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_get(self, client: Fireworks) -> None:
        dataset = client.datasets.get(
            dataset_id="dataset_id",
            account_id="account_id",
        )
        assert_matches_type(Dataset, dataset, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_get_with_all_params(self, client: Fireworks) -> None:
        dataset = client.datasets.get(
            dataset_id="dataset_id",
            account_id="account_id",
            read_mask="readMask",
        )
        assert_matches_type(Dataset, dataset, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_get(self, client: Fireworks) -> None:
        response = client.datasets.with_raw_response.get(
            dataset_id="dataset_id",
            account_id="account_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        dataset = response.parse()
        assert_matches_type(Dataset, dataset, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_get(self, client: Fireworks) -> None:
        with client.datasets.with_streaming_response.get(
            dataset_id="dataset_id",
            account_id="account_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            dataset = response.parse()
            assert_matches_type(Dataset, dataset, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_get(self, client: Fireworks) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `account_id` but received ''"):
            client.datasets.with_raw_response.get(
                dataset_id="dataset_id",
                account_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `dataset_id` but received ''"):
            client.datasets.with_raw_response.get(
                dataset_id="",
                account_id="account_id",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_get_download_endpoint(self, client: Fireworks) -> None:
        dataset = client.datasets.get_download_endpoint(
            dataset_id="dataset_id",
            account_id="account_id",
        )
        assert_matches_type(DatasetGetDownloadEndpointResponse, dataset, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_get_download_endpoint_with_all_params(self, client: Fireworks) -> None:
        dataset = client.datasets.get_download_endpoint(
            dataset_id="dataset_id",
            account_id="account_id",
            download_lineage=True,
            read_mask="readMask",
        )
        assert_matches_type(DatasetGetDownloadEndpointResponse, dataset, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_get_download_endpoint(self, client: Fireworks) -> None:
        response = client.datasets.with_raw_response.get_download_endpoint(
            dataset_id="dataset_id",
            account_id="account_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        dataset = response.parse()
        assert_matches_type(DatasetGetDownloadEndpointResponse, dataset, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_get_download_endpoint(self, client: Fireworks) -> None:
        with client.datasets.with_streaming_response.get_download_endpoint(
            dataset_id="dataset_id",
            account_id="account_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            dataset = response.parse()
            assert_matches_type(DatasetGetDownloadEndpointResponse, dataset, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_get_download_endpoint(self, client: Fireworks) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `account_id` but received ''"):
            client.datasets.with_raw_response.get_download_endpoint(
                dataset_id="dataset_id",
                account_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `dataset_id` but received ''"):
            client.datasets.with_raw_response.get_download_endpoint(
                dataset_id="",
                account_id="account_id",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_get_upload_endpoint(self, client: Fireworks) -> None:
        dataset = client.datasets.get_upload_endpoint(
            dataset_id="dataset_id",
            account_id="account_id",
            filename_to_size={"foo": "string"},
        )
        assert_matches_type(DatasetGetUploadEndpointResponse, dataset, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_get_upload_endpoint_with_all_params(self, client: Fireworks) -> None:
        dataset = client.datasets.get_upload_endpoint(
            dataset_id="dataset_id",
            account_id="account_id",
            filename_to_size={"foo": "string"},
            read_mask="readMask",
        )
        assert_matches_type(DatasetGetUploadEndpointResponse, dataset, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_get_upload_endpoint(self, client: Fireworks) -> None:
        response = client.datasets.with_raw_response.get_upload_endpoint(
            dataset_id="dataset_id",
            account_id="account_id",
            filename_to_size={"foo": "string"},
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        dataset = response.parse()
        assert_matches_type(DatasetGetUploadEndpointResponse, dataset, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_get_upload_endpoint(self, client: Fireworks) -> None:
        with client.datasets.with_streaming_response.get_upload_endpoint(
            dataset_id="dataset_id",
            account_id="account_id",
            filename_to_size={"foo": "string"},
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            dataset = response.parse()
            assert_matches_type(DatasetGetUploadEndpointResponse, dataset, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_get_upload_endpoint(self, client: Fireworks) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `account_id` but received ''"):
            client.datasets.with_raw_response.get_upload_endpoint(
                dataset_id="dataset_id",
                account_id="",
                filename_to_size={"foo": "string"},
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `dataset_id` but received ''"):
            client.datasets.with_raw_response.get_upload_endpoint(
                dataset_id="",
                account_id="account_id",
                filename_to_size={"foo": "string"},
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_upload(self, client: Fireworks) -> None:
        dataset = client.datasets.upload(
            dataset_id="dataset_id",
            account_id="account_id",
        )
        assert_matches_type(DatasetUploadResponse, dataset, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_upload_with_all_params(self, client: Fireworks) -> None:
        dataset = client.datasets.upload(
            dataset_id="dataset_id",
            account_id="account_id",
            file=b"raw file contents",
        )
        assert_matches_type(DatasetUploadResponse, dataset, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_upload(self, client: Fireworks) -> None:
        response = client.datasets.with_raw_response.upload(
            dataset_id="dataset_id",
            account_id="account_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        dataset = response.parse()
        assert_matches_type(DatasetUploadResponse, dataset, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_upload(self, client: Fireworks) -> None:
        with client.datasets.with_streaming_response.upload(
            dataset_id="dataset_id",
            account_id="account_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            dataset = response.parse()
            assert_matches_type(DatasetUploadResponse, dataset, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_upload(self, client: Fireworks) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `account_id` but received ''"):
            client.datasets.with_raw_response.upload(
                dataset_id="dataset_id",
                account_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `dataset_id` but received ''"):
            client.datasets.with_raw_response.upload(
                dataset_id="",
                account_id="account_id",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_validate_upload(self, client: Fireworks) -> None:
        dataset = client.datasets.validate_upload(
            dataset_id="dataset_id",
            account_id="account_id",
            body={},
        )
        assert_matches_type(object, dataset, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_validate_upload(self, client: Fireworks) -> None:
        response = client.datasets.with_raw_response.validate_upload(
            dataset_id="dataset_id",
            account_id="account_id",
            body={},
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        dataset = response.parse()
        assert_matches_type(object, dataset, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_validate_upload(self, client: Fireworks) -> None:
        with client.datasets.with_streaming_response.validate_upload(
            dataset_id="dataset_id",
            account_id="account_id",
            body={},
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            dataset = response.parse()
            assert_matches_type(object, dataset, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_validate_upload(self, client: Fireworks) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `account_id` but received ''"):
            client.datasets.with_raw_response.validate_upload(
                dataset_id="dataset_id",
                account_id="",
                body={},
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `dataset_id` but received ''"):
            client.datasets.with_raw_response.validate_upload(
                dataset_id="",
                account_id="account_id",
                body={},
            )


class TestAsyncDatasets:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_create(self, async_client: AsyncFireworks) -> None:
        dataset = await async_client.datasets.create(
            account_id="account_id",
            dataset={},
            dataset_id="datasetId",
        )
        assert_matches_type(Dataset, dataset, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_create_with_all_params(self, async_client: AsyncFireworks) -> None:
        dataset = await async_client.datasets.create(
            account_id="account_id",
            dataset={
                "display_name": "displayName",
                "eval_protocol": {},
                "evaluation_result": {"evaluation_job_id": "evaluationJobId"},
                "example_count": "exampleCount",
                "external_url": "externalUrl",
                "format": "FORMAT_UNSPECIFIED",
                "source_job_name": "sourceJobName",
                "splitted": {"source_dataset_id": "sourceDatasetId"},
                "transformed": {
                    "source_dataset_id": "sourceDatasetId",
                    "filter": "filter",
                    "original_format": "FORMAT_UNSPECIFIED",
                },
                "user_uploaded": {},
            },
            dataset_id="datasetId",
            filter="filter",
            source_dataset_id="sourceDatasetId",
        )
        assert_matches_type(Dataset, dataset, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_create(self, async_client: AsyncFireworks) -> None:
        response = await async_client.datasets.with_raw_response.create(
            account_id="account_id",
            dataset={},
            dataset_id="datasetId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        dataset = await response.parse()
        assert_matches_type(Dataset, dataset, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncFireworks) -> None:
        async with async_client.datasets.with_streaming_response.create(
            account_id="account_id",
            dataset={},
            dataset_id="datasetId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            dataset = await response.parse()
            assert_matches_type(Dataset, dataset, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_create(self, async_client: AsyncFireworks) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `account_id` but received ''"):
            await async_client.datasets.with_raw_response.create(
                account_id="",
                dataset={},
                dataset_id="datasetId",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_update(self, async_client: AsyncFireworks) -> None:
        dataset = await async_client.datasets.update(
            dataset_id="dataset_id",
            account_id="account_id",
        )
        assert_matches_type(Dataset, dataset, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_update_with_all_params(self, async_client: AsyncFireworks) -> None:
        dataset = await async_client.datasets.update(
            dataset_id="dataset_id",
            account_id="account_id",
            display_name="displayName",
            eval_protocol={},
            evaluation_result={"evaluation_job_id": "evaluationJobId"},
            example_count="exampleCount",
            external_url="externalUrl",
            format="FORMAT_UNSPECIFIED",
            source_job_name="sourceJobName",
            splitted={"source_dataset_id": "sourceDatasetId"},
            transformed={
                "source_dataset_id": "sourceDatasetId",
                "filter": "filter",
                "original_format": "FORMAT_UNSPECIFIED",
            },
            user_uploaded={},
        )
        assert_matches_type(Dataset, dataset, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_update(self, async_client: AsyncFireworks) -> None:
        response = await async_client.datasets.with_raw_response.update(
            dataset_id="dataset_id",
            account_id="account_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        dataset = await response.parse()
        assert_matches_type(Dataset, dataset, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_update(self, async_client: AsyncFireworks) -> None:
        async with async_client.datasets.with_streaming_response.update(
            dataset_id="dataset_id",
            account_id="account_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            dataset = await response.parse()
            assert_matches_type(Dataset, dataset, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_update(self, async_client: AsyncFireworks) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `account_id` but received ''"):
            await async_client.datasets.with_raw_response.update(
                dataset_id="dataset_id",
                account_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `dataset_id` but received ''"):
            await async_client.datasets.with_raw_response.update(
                dataset_id="",
                account_id="account_id",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list(self, async_client: AsyncFireworks) -> None:
        dataset = await async_client.datasets.list(
            account_id="account_id",
        )
        assert_matches_type(AsyncCursorDatasets[Dataset], dataset, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list_with_all_params(self, async_client: AsyncFireworks) -> None:
        dataset = await async_client.datasets.list(
            account_id="account_id",
            filter="filter",
            order_by="orderBy",
            page_size=0,
            page_token="pageToken",
            read_mask="readMask",
        )
        assert_matches_type(AsyncCursorDatasets[Dataset], dataset, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_list(self, async_client: AsyncFireworks) -> None:
        response = await async_client.datasets.with_raw_response.list(
            account_id="account_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        dataset = await response.parse()
        assert_matches_type(AsyncCursorDatasets[Dataset], dataset, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncFireworks) -> None:
        async with async_client.datasets.with_streaming_response.list(
            account_id="account_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            dataset = await response.parse()
            assert_matches_type(AsyncCursorDatasets[Dataset], dataset, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_list(self, async_client: AsyncFireworks) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `account_id` but received ''"):
            await async_client.datasets.with_raw_response.list(
                account_id="",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_delete(self, async_client: AsyncFireworks) -> None:
        dataset = await async_client.datasets.delete(
            dataset_id="dataset_id",
            account_id="account_id",
        )
        assert_matches_type(object, dataset, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_delete(self, async_client: AsyncFireworks) -> None:
        response = await async_client.datasets.with_raw_response.delete(
            dataset_id="dataset_id",
            account_id="account_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        dataset = await response.parse()
        assert_matches_type(object, dataset, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_delete(self, async_client: AsyncFireworks) -> None:
        async with async_client.datasets.with_streaming_response.delete(
            dataset_id="dataset_id",
            account_id="account_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            dataset = await response.parse()
            assert_matches_type(object, dataset, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_delete(self, async_client: AsyncFireworks) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `account_id` but received ''"):
            await async_client.datasets.with_raw_response.delete(
                dataset_id="dataset_id",
                account_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `dataset_id` but received ''"):
            await async_client.datasets.with_raw_response.delete(
                dataset_id="",
                account_id="account_id",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_get(self, async_client: AsyncFireworks) -> None:
        dataset = await async_client.datasets.get(
            dataset_id="dataset_id",
            account_id="account_id",
        )
        assert_matches_type(Dataset, dataset, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_get_with_all_params(self, async_client: AsyncFireworks) -> None:
        dataset = await async_client.datasets.get(
            dataset_id="dataset_id",
            account_id="account_id",
            read_mask="readMask",
        )
        assert_matches_type(Dataset, dataset, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_get(self, async_client: AsyncFireworks) -> None:
        response = await async_client.datasets.with_raw_response.get(
            dataset_id="dataset_id",
            account_id="account_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        dataset = await response.parse()
        assert_matches_type(Dataset, dataset, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_get(self, async_client: AsyncFireworks) -> None:
        async with async_client.datasets.with_streaming_response.get(
            dataset_id="dataset_id",
            account_id="account_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            dataset = await response.parse()
            assert_matches_type(Dataset, dataset, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_get(self, async_client: AsyncFireworks) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `account_id` but received ''"):
            await async_client.datasets.with_raw_response.get(
                dataset_id="dataset_id",
                account_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `dataset_id` but received ''"):
            await async_client.datasets.with_raw_response.get(
                dataset_id="",
                account_id="account_id",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_get_download_endpoint(self, async_client: AsyncFireworks) -> None:
        dataset = await async_client.datasets.get_download_endpoint(
            dataset_id="dataset_id",
            account_id="account_id",
        )
        assert_matches_type(DatasetGetDownloadEndpointResponse, dataset, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_get_download_endpoint_with_all_params(self, async_client: AsyncFireworks) -> None:
        dataset = await async_client.datasets.get_download_endpoint(
            dataset_id="dataset_id",
            account_id="account_id",
            download_lineage=True,
            read_mask="readMask",
        )
        assert_matches_type(DatasetGetDownloadEndpointResponse, dataset, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_get_download_endpoint(self, async_client: AsyncFireworks) -> None:
        response = await async_client.datasets.with_raw_response.get_download_endpoint(
            dataset_id="dataset_id",
            account_id="account_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        dataset = await response.parse()
        assert_matches_type(DatasetGetDownloadEndpointResponse, dataset, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_get_download_endpoint(self, async_client: AsyncFireworks) -> None:
        async with async_client.datasets.with_streaming_response.get_download_endpoint(
            dataset_id="dataset_id",
            account_id="account_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            dataset = await response.parse()
            assert_matches_type(DatasetGetDownloadEndpointResponse, dataset, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_get_download_endpoint(self, async_client: AsyncFireworks) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `account_id` but received ''"):
            await async_client.datasets.with_raw_response.get_download_endpoint(
                dataset_id="dataset_id",
                account_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `dataset_id` but received ''"):
            await async_client.datasets.with_raw_response.get_download_endpoint(
                dataset_id="",
                account_id="account_id",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_get_upload_endpoint(self, async_client: AsyncFireworks) -> None:
        dataset = await async_client.datasets.get_upload_endpoint(
            dataset_id="dataset_id",
            account_id="account_id",
            filename_to_size={"foo": "string"},
        )
        assert_matches_type(DatasetGetUploadEndpointResponse, dataset, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_get_upload_endpoint_with_all_params(self, async_client: AsyncFireworks) -> None:
        dataset = await async_client.datasets.get_upload_endpoint(
            dataset_id="dataset_id",
            account_id="account_id",
            filename_to_size={"foo": "string"},
            read_mask="readMask",
        )
        assert_matches_type(DatasetGetUploadEndpointResponse, dataset, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_get_upload_endpoint(self, async_client: AsyncFireworks) -> None:
        response = await async_client.datasets.with_raw_response.get_upload_endpoint(
            dataset_id="dataset_id",
            account_id="account_id",
            filename_to_size={"foo": "string"},
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        dataset = await response.parse()
        assert_matches_type(DatasetGetUploadEndpointResponse, dataset, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_get_upload_endpoint(self, async_client: AsyncFireworks) -> None:
        async with async_client.datasets.with_streaming_response.get_upload_endpoint(
            dataset_id="dataset_id",
            account_id="account_id",
            filename_to_size={"foo": "string"},
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            dataset = await response.parse()
            assert_matches_type(DatasetGetUploadEndpointResponse, dataset, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_get_upload_endpoint(self, async_client: AsyncFireworks) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `account_id` but received ''"):
            await async_client.datasets.with_raw_response.get_upload_endpoint(
                dataset_id="dataset_id",
                account_id="",
                filename_to_size={"foo": "string"},
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `dataset_id` but received ''"):
            await async_client.datasets.with_raw_response.get_upload_endpoint(
                dataset_id="",
                account_id="account_id",
                filename_to_size={"foo": "string"},
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_upload(self, async_client: AsyncFireworks) -> None:
        dataset = await async_client.datasets.upload(
            dataset_id="dataset_id",
            account_id="account_id",
        )
        assert_matches_type(DatasetUploadResponse, dataset, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_upload_with_all_params(self, async_client: AsyncFireworks) -> None:
        dataset = await async_client.datasets.upload(
            dataset_id="dataset_id",
            account_id="account_id",
            file=b"raw file contents",
        )
        assert_matches_type(DatasetUploadResponse, dataset, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_upload(self, async_client: AsyncFireworks) -> None:
        response = await async_client.datasets.with_raw_response.upload(
            dataset_id="dataset_id",
            account_id="account_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        dataset = await response.parse()
        assert_matches_type(DatasetUploadResponse, dataset, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_upload(self, async_client: AsyncFireworks) -> None:
        async with async_client.datasets.with_streaming_response.upload(
            dataset_id="dataset_id",
            account_id="account_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            dataset = await response.parse()
            assert_matches_type(DatasetUploadResponse, dataset, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_upload(self, async_client: AsyncFireworks) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `account_id` but received ''"):
            await async_client.datasets.with_raw_response.upload(
                dataset_id="dataset_id",
                account_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `dataset_id` but received ''"):
            await async_client.datasets.with_raw_response.upload(
                dataset_id="",
                account_id="account_id",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_validate_upload(self, async_client: AsyncFireworks) -> None:
        dataset = await async_client.datasets.validate_upload(
            dataset_id="dataset_id",
            account_id="account_id",
            body={},
        )
        assert_matches_type(object, dataset, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_validate_upload(self, async_client: AsyncFireworks) -> None:
        response = await async_client.datasets.with_raw_response.validate_upload(
            dataset_id="dataset_id",
            account_id="account_id",
            body={},
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        dataset = await response.parse()
        assert_matches_type(object, dataset, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_validate_upload(self, async_client: AsyncFireworks) -> None:
        async with async_client.datasets.with_streaming_response.validate_upload(
            dataset_id="dataset_id",
            account_id="account_id",
            body={},
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            dataset = await response.parse()
            assert_matches_type(object, dataset, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_validate_upload(self, async_client: AsyncFireworks) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `account_id` but received ''"):
            await async_client.datasets.with_raw_response.validate_upload(
                dataset_id="dataset_id",
                account_id="",
                body={},
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `dataset_id` but received ''"):
            await async_client.datasets.with_raw_response.validate_upload(
                dataset_id="",
                account_id="account_id",
                body={},
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["DpoJobGetMetricsFileEndpointResponse"]


class DpoJobGetMetricsFileEndpointResponse(BaseModel):
    signed_url: Optional[str] = FieldInfo(alias="signedUrl", default=None)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import datetime
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .._models import BaseModel
from .shared.status import Status

__all__ = ["Account"]


class Account(BaseModel):
    email: str
    """For developer accounts, this is the email of the developer user and is
    immutable.

    For ENTERPRISE and BUSINESS accounts, this is mutable and it is the email that
    will recieve the invoice for the account if automated billing is used.
    """

    create_time: Optional[datetime] = FieldInfo(alias="createTime", default=None)
    """The creation time of the account."""

    display_name: Optional[str] = FieldInfo(alias="displayName", default=None)
    """Human-readable display name of the account.

    e.g. "My Account" Must be fewer than 64 characters long.
    """

    name: Optional[str] = None

    state: Optional[Literal["STATE_UNSPECIFIED", "CREATING", "READY", "UPDATING", "DELETING"]] = None
    """The state of the account."""

    status: Optional[Status] = None
    """Contains information about the account status."""

    suspend_state: Optional[
        Literal[
            "UNSUSPENDED", "FAILED_PAYMENTS", "CREDIT_DEPLETED", "MONTHLY_SPEND_LIMIT_EXCEEDED", "BLOCKED_BY_ABUSE_RULE"
        ]
    ] = FieldInfo(alias="suspendState", default=None)

    update_time: Optional[datetime] = FieldInfo(alias="updateTime", default=None)
    """The update time for the account."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import TYPE_CHECKING, Any, Mapping
from typing_extensions import Self, override

import httpx

from . import _exceptions
from ._qs import Querystring
from ._types import (
    Omit,
    Timeout,
    NotGiven,
    Transport,
    ProxiesTypes,
    RequestOptions,
    not_given,
)
from ._utils import is_given, get_async_library
from ._compat import cached_property
from ._version import __version__
from ._streaming import Stream as Stream, AsyncStream as AsyncStream
from ._exceptions import APIStatusError, FireworksError
from ._base_client import (
    DEFAULT_MAX_RETRIES,
    SyncAPIClient,
    AsyncAPIClient,
)

if TYPE_CHECKING:
    from .resources import (
        chat,
        lora,
        users,
        models,
        secrets,
        accounts,
        api_keys,
        datasets,
        dpo_jobs,
        evaluators,
        completions,
        deployments,
        evaluation_jobs,
        batch_inference_jobs,
        deployment_shape_versions,
        supervised_fine_tuning_jobs,
        reinforcement_fine_tuning_jobs,
        reinforcement_fine_tuning_steps,
    )
    from .resources.lora import LoraResource, AsyncLoraResource
    from .resources.users import UsersResource, AsyncUsersResource
    from .resources.models import ModelsResource, AsyncModelsResource
    from .resources.secrets import SecretsResource, AsyncSecretsResource
    from .resources.accounts import AccountsResource, AsyncAccountsResource
    from .resources.api_keys import APIKeysResource, AsyncAPIKeysResource
    from .resources.datasets import DatasetsResource, AsyncDatasetsResource
    from .resources.dpo_jobs import DpoJobsResource, AsyncDpoJobsResource
    from .resources.chat.chat import ChatResource, AsyncChatResource
    from .resources.evaluators import EvaluatorsResource, AsyncEvaluatorsResource
    from .resources.completions import CompletionsResource, AsyncCompletionsResource
    from .resources.deployments import DeploymentsResource, AsyncDeploymentsResource
    from .resources.evaluation_jobs import EvaluationJobsResource, AsyncEvaluationJobsResource
    from .resources.batch_inference_jobs import BatchInferenceJobsResource, AsyncBatchInferenceJobsResource
    from .resources.deployment_shape_versions import (
        DeploymentShapeVersionsResource,
        AsyncDeploymentShapeVersionsResource,
    )
    from .resources.supervised_fine_tuning_jobs import (
        SupervisedFineTuningJobsResource,
        AsyncSupervisedFineTuningJobsResource,
    )
    from .resources.reinforcement_fine_tuning_jobs import (
        ReinforcementFineTuningJobsResource,
        AsyncReinforcementFineTuningJobsResource,
    )
    from .resources.reinforcement_fine_tuning_steps import (
        ReinforcementFineTuningStepsResource,
        AsyncReinforcementFineTuningStepsResource,
    )

__all__ = [
    "Timeout",
    "Transport",
    "ProxiesTypes",
    "RequestOptions",
    "Fireworks",
    "AsyncFireworks",
    "Client",
    "AsyncClient",
]


class Fireworks(SyncAPIClient):
    # client options
    api_key: str
    account_id: str | None

    def __init__(
        self,
        *,
        api_key: str | None = None,
        account_id: str | None = None,
        base_url: str | httpx.URL | None = None,
        timeout: float | Timeout | None | NotGiven = not_given,
        max_retries: int = DEFAULT_MAX_RETRIES,
        default_headers: Mapping[str, str] | None = None,
        default_query: Mapping[str, object] | None = None,
        # Configure a custom httpx client.
        # We provide a `DefaultHttpxClient` class that you can pass to retain the default values we use for `limits`, `timeout` & `follow_redirects`.
        # See the [httpx documentation](https://www.python-httpx.org/api/#client) for more details.
        http_client: httpx.Client | None = None,
        # Enable or disable schema validation for data returned by the API.
        # When enabled an error APIResponseValidationError is raised
        # if the API responds with invalid data for the expected schema.
        #
        # This parameter may be removed or changed in the future.
        # If you rely on this feature, please open a GitHub issue
        # outlining your use-case to help us decide if it should be
        # part of our public interface in the future.
        _strict_response_validation: bool = False,
    ) -> None:
        """Construct a new synchronous Fireworks client instance.

        This automatically infers the following arguments from their corresponding environment variables if they are not provided:
        - `api_key` from `FIREWORKS_API_KEY`
        - `account_id` from `FIREWORKS_ACCOUNT_ID`
        """
        if api_key is None:
            api_key = os.environ.get("FIREWORKS_API_KEY")
        if api_key is None:
            raise FireworksError(
                "The api_key client option must be set either by passing api_key to the client or by setting the FIREWORKS_API_KEY environment variable"
            )
        self.api_key = api_key

        if account_id is None:
            account_id = os.environ.get("FIREWORKS_ACCOUNT_ID")
        self.account_id = account_id

        if base_url is None:
            base_url = os.environ.get("FIREWORKS_BASE_URL")
        self._base_url_overridden = base_url is not None
        if base_url is None:
            base_url = f"https://api.fireworks.ai"

        super().__init__(
            version=__version__,
            base_url=base_url,
            max_retries=max_retries,
            timeout=timeout,
            http_client=http_client,
            custom_headers=default_headers,
            custom_query=default_query,
            _strict_response_validation=_strict_response_validation,
        )

        self._default_stream_cls = Stream

    @cached_property
    def chat(self) -> ChatResource:
        from .resources.chat import ChatResource

        return ChatResource(self)

    @cached_property
    def completions(self) -> CompletionsResource:
        from .resources.completions import CompletionsResource

        return CompletionsResource(self)

    @cached_property
    def batch_inference_jobs(self) -> BatchInferenceJobsResource:
        from .resources.batch_inference_jobs import BatchInferenceJobsResource

        return BatchInferenceJobsResource(self)

    @cached_property
    def deployments(self) -> DeploymentsResource:
        from .resources.deployments import DeploymentsResource

        return DeploymentsResource(self)

    @cached_property
    def models(self) -> ModelsResource:
        from .resources.models import ModelsResource

        return ModelsResource(self)

    @cached_property
    def lora(self) -> LoraResource:
        from .resources.lora import LoraResource

        return LoraResource(self)

    @cached_property
    def deployment_shape_versions(self) -> DeploymentShapeVersionsResource:
        from .resources.deployment_shape_versions import DeploymentShapeVersionsResource

        return DeploymentShapeVersionsResource(self)

    @cached_property
    def datasets(self) -> DatasetsResource:
        from .resources.datasets import DatasetsResource

        return DatasetsResource(self)

    @cached_property
    def supervised_fine_tuning_jobs(self) -> SupervisedFineTuningJobsResource:
        from .resources.supervised_fine_tuning_jobs import SupervisedFineTuningJobsResource

        return SupervisedFineTuningJobsResource(self)

    @cached_property
    def reinforcement_fine_tuning_jobs(self) -> ReinforcementFineTuningJobsResource:
        from .resources.reinforcement_fine_tuning_jobs import ReinforcementFineTuningJobsResource

        return ReinforcementFineTuningJobsResource(self)

    @cached_property
    def reinforcement_fine_tuning_steps(self) -> ReinforcementFineTuningStepsResource:
        from .resources.reinforcement_fine_tuning_steps import ReinforcementFineTuningStepsResource

        return ReinforcementFineTuningStepsResource(self)

    @cached_property
    def dpo_jobs(self) -> DpoJobsResource:
        from .resources.dpo_jobs import DpoJobsResource

        return DpoJobsResource(self)

    @cached_property
    def evaluation_jobs(self) -> EvaluationJobsResource:
        from .resources.evaluation_jobs import EvaluationJobsResource

        return EvaluationJobsResource(self)

    @cached_property
    def evaluators(self) -> EvaluatorsResource:
        from .resources.evaluators import EvaluatorsResource

        return EvaluatorsResource(self)

    @cached_property
    def accounts(self) -> AccountsResource:
        from .resources.accounts import AccountsResource

        return AccountsResource(self)

    @cached_property
    def users(self) -> UsersResource:
        from .resources.users import UsersResource

        return UsersResource(self)

    @cached_property
    def api_keys(self) -> APIKeysResource:
        from .resources.api_keys import APIKeysResource

        return APIKeysResource(self)

    @cached_property
    def secrets(self) -> SecretsResource:
        from .resources.secrets import SecretsResource

        return SecretsResource(self)

    @cached_property
    def with_raw_response(self) -> FireworksWithRawResponse:
        return FireworksWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> FireworksWithStreamedResponse:
        return FireworksWithStreamedResponse(self)

    @property
    @override
    def qs(self) -> Querystring:
        return Querystring(array_format="comma")

    @property
    @override
    def auth_headers(self) -> dict[str, str]:
        api_key = self.api_key
        return {"Authorization": f"Bearer {api_key}"}

    @property
    @override
    def default_headers(self) -> dict[str, str | Omit]:
        return {
            **super().default_headers,
            "X-Stainless-Async": "false",
            **self._custom_headers,
        }

    def copy(
        self,
        *,
        api_key: str | None = None,
        account_id: str | None = None,
        base_url: str | httpx.URL | None = None,
        timeout: float | Timeout | None | NotGiven = not_given,
        http_client: httpx.Client | None = None,
        max_retries: int | NotGiven = not_given,
        default_headers: Mapping[str, str] | None = None,
        set_default_headers: Mapping[str, str] | None = None,
        default_query: Mapping[str, object] | None = None,
        set_default_query: Mapping[str, object] | None = None,
        _extra_kwargs: Mapping[str, Any] = {},
    ) -> Self:
        """
        Create a new client instance re-using the same options given to the current client with optional overriding.
        """
        if default_headers is not None and set_default_headers is not None:
            raise ValueError("The `default_headers` and `set_default_headers` arguments are mutually exclusive")

        if default_query is not None and set_default_query is not None:
            raise ValueError("The `default_query` and `set_default_query` arguments are mutually exclusive")

        headers = self._custom_headers
        if default_headers is not None:
            headers = {**headers, **default_headers}
        elif set_default_headers is not None:
            headers = set_default_headers

        params = self._custom_query
        if default_query is not None:
            params = {**params, **default_query}
        elif set_default_query is not None:
            params = set_default_query

        http_client = http_client or self._client
        client = self.__class__(
            api_key=api_key or self.api_key,
            account_id=account_id or self.account_id,
            base_url=base_url or self.base_url,
            timeout=self.timeout if isinstance(timeout, NotGiven) else timeout,
            http_client=http_client,
            max_retries=max_retries if is_given(max_retries) else self.max_retries,
            default_headers=headers,
            default_query=params,
            **_extra_kwargs,
        )
        client._base_url_overridden = self._base_url_overridden or base_url is not None
        return client

    # Alias for `copy` for nicer inline usage, e.g.
    # client.with_options(timeout=10).foo.create(...)
    with_options = copy

    def _get_account_id_path_param(self) -> str:
        from_client = self.account_id
        if from_client is not None:
            return from_client

        raise ValueError(
            "Missing account_id argument; Please provide it at the client level, e.g. Fireworks(account_id='abcd') or per method."
        )

    @override
    def _make_status_error(
        self,
        err_msg: str,
        *,
        body: object,
        response: httpx.Response,
    ) -> APIStatusError:
        if response.status_code == 400:
            return _exceptions.BadRequestError(err_msg, response=response, body=body)

        if response.status_code == 401:
            return _exceptions.AuthenticationError(err_msg, response=response, body=body)

        if response.status_code == 403:
            return _exceptions.PermissionDeniedError(err_msg, response=response, body=body)

        if response.status_code == 404:
            return _exceptions.NotFoundError(err_msg, response=response, body=body)

        if response.status_code == 409:
            return _exceptions.ConflictError(err_msg, response=response, body=body)

        if response.status_code == 422:
            return _exceptions.UnprocessableEntityError(err_msg, response=response, body=body)

        if response.status_code == 429:
            return _exceptions.RateLimitError(err_msg, response=response, body=body)

        if response.status_code >= 500:
            return _exceptions.InternalServerError(err_msg, response=response, body=body)
        return APIStatusError(err_msg, response=response, body=body)


class AsyncFireworks(AsyncAPIClient):
    # client options
    api_key: str
    account_id: str | None

    def __init__(
        self,
        *,
        api_key: str | None = None,
        account_id: str | None = None,
        base_url: str | httpx.URL | None = None,
        timeout: float | Timeout | None | NotGiven = not_given,
        max_retries: int = DEFAULT_MAX_RETRIES,
        default_headers: Mapping[str, str] | None = None,
        default_query: Mapping[str, object] | None = None,
        # Configure a custom httpx client.
        # We provide a `DefaultAsyncHttpxClient` class that you can pass to retain the default values we use for `limits`, `timeout` & `follow_redirects`.
        # See the [httpx documentation](https://www.python-httpx.org/api/#asyncclient) for more details.
        http_client: httpx.AsyncClient | None = None,
        # Enable or disable schema validation for data returned by the API.
        # When enabled an error APIResponseValidationError is raised
        # if the API responds with invalid data for the expected schema.
        #
        # This parameter may be removed or changed in the future.
        # If you rely on this feature, please open a GitHub issue
        # outlining your use-case to help us decide if it should be
        # part of our public interface in the future.
        _strict_response_validation: bool = False,
    ) -> None:
        """Construct a new async AsyncFireworks client instance.

        This automatically infers the following arguments from their corresponding environment variables if they are not provided:
        - `api_key` from `FIREWORKS_API_KEY`
        - `account_id` from `FIREWORKS_ACCOUNT_ID`
        """
        if api_key is None:
            api_key = os.environ.get("FIREWORKS_API_KEY")
        if api_key is None:
            raise FireworksError(
                "The api_key client option must be set either by passing api_key to the client or by setting the FIREWORKS_API_KEY environment variable"
            )
        self.api_key = api_key

        if account_id is None:
            account_id = os.environ.get("FIREWORKS_ACCOUNT_ID")
        self.account_id = account_id

        if base_url is None:
            base_url = os.environ.get("FIREWORKS_BASE_URL")
        self._base_url_overridden = base_url is not None
        if base_url is None:
            base_url = f"https://api.fireworks.ai"

        super().__init__(
            version=__version__,
            base_url=base_url,
            max_retries=max_retries,
            timeout=timeout,
            http_client=http_client,
            custom_headers=default_headers,
            custom_query=default_query,
            _strict_response_validation=_strict_response_validation,
        )

        self._default_stream_cls = AsyncStream

    @cached_property
    def chat(self) -> AsyncChatResource:
        from .resources.chat import AsyncChatResource

        return AsyncChatResource(self)

    @cached_property
    def completions(self) -> AsyncCompletionsResource:
        from .resources.completions import AsyncCompletionsResource

        return AsyncCompletionsResource(self)

    @cached_property
    def batch_inference_jobs(self) -> AsyncBatchInferenceJobsResource:
        from .resources.batch_inference_jobs import AsyncBatchInferenceJobsResource

        return AsyncBatchInferenceJobsResource(self)

    @cached_property
    def deployments(self) -> AsyncDeploymentsResource:
        from .resources.deployments import AsyncDeploymentsResource

        return AsyncDeploymentsResource(self)

    @cached_property
    def models(self) -> AsyncModelsResource:
        from .resources.models import AsyncModelsResource

        return AsyncModelsResource(self)

    @cached_property
    def lora(self) -> AsyncLoraResource:
        from .resources.lora import AsyncLoraResource

        return AsyncLoraResource(self)

    @cached_property
    def deployment_shape_versions(self) -> AsyncDeploymentShapeVersionsResource:
        from .resources.deployment_shape_versions import AsyncDeploymentShapeVersionsResource

        return AsyncDeploymentShapeVersionsResource(self)

    @cached_property
    def datasets(self) -> AsyncDatasetsResource:
        from .resources.datasets import AsyncDatasetsResource

        return AsyncDatasetsResource(self)

    @cached_property
    def supervised_fine_tuning_jobs(self) -> AsyncSupervisedFineTuningJobsResource:
        from .resources.supervised_fine_tuning_jobs import AsyncSupervisedFineTuningJobsResource

        return AsyncSupervisedFineTuningJobsResource(self)

    @cached_property
    def reinforcement_fine_tuning_jobs(self) -> AsyncReinforcementFineTuningJobsResource:
        from .resources.reinforcement_fine_tuning_jobs import AsyncReinforcementFineTuningJobsResource

        return AsyncReinforcementFineTuningJobsResource(self)

    @cached_property
    def reinforcement_fine_tuning_steps(self) -> AsyncReinforcementFineTuningStepsResource:
        from .resources.reinforcement_fine_tuning_steps import AsyncReinforcementFineTuningStepsResource

        return AsyncReinforcementFineTuningStepsResource(self)

    @cached_property
    def dpo_jobs(self) -> AsyncDpoJobsResource:
        from .resources.dpo_jobs import AsyncDpoJobsResource

        return AsyncDpoJobsResource(self)

    @cached_property
    def evaluation_jobs(self) -> AsyncEvaluationJobsResource:
        from .resources.evaluation_jobs import AsyncEvaluationJobsResource

        return AsyncEvaluationJobsResource(self)

    @cached_property
    def evaluators(self) -> AsyncEvaluatorsResource:
        from .resources.evaluators import AsyncEvaluatorsResource

        return AsyncEvaluatorsResource(self)

    @cached_property
    def accounts(self) -> AsyncAccountsResource:
        from .resources.accounts import AsyncAccountsResource

        return AsyncAccountsResource(self)

    @cached_property
    def users(self) -> AsyncUsersResource:
        from .resources.users import AsyncUsersResource

        return AsyncUsersResource(self)

    @cached_property
    def api_keys(self) -> AsyncAPIKeysResource:
        from .resources.api_keys import AsyncAPIKeysResource

        return AsyncAPIKeysResource(self)

    @cached_property
    def secrets(self) -> AsyncSecretsResource:
        from .resources.secrets import AsyncSecretsResource

        return AsyncSecretsResource(self)

    @cached_property
    def with_raw_response(self) -> AsyncFireworksWithRawResponse:
        return AsyncFireworksWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncFireworksWithStreamedResponse:
        return AsyncFireworksWithStreamedResponse(self)

    @property
    @override
    def qs(self) -> Querystring:
        return Querystring(array_format="comma")

    @property
    @override
    def auth_headers(self) -> dict[str, str]:
        api_key = self.api_key
        return {"Authorization": f"Bearer {api_key}"}

    @property
    @override
    def default_headers(self) -> dict[str, str | Omit]:
        return {
            **super().default_headers,
            "X-Stainless-Async": f"async:{get_async_library()}",
            **self._custom_headers,
        }

    def copy(
        self,
        *,
        api_key: str | None = None,
        account_id: str | None = None,
        base_url: str | httpx.URL | None = None,
        timeout: float | Timeout | None | NotGiven = not_given,
        http_client: httpx.AsyncClient | None = None,
        max_retries: int | NotGiven = not_given,
        default_headers: Mapping[str, str] | None = None,
        set_default_headers: Mapping[str, str] | None = None,
        default_query: Mapping[str, object] | None = None,
        set_default_query: Mapping[str, object] | None = None,
        _extra_kwargs: Mapping[str, Any] = {},
    ) -> Self:
        """
        Create a new client instance re-using the same options given to the current client with optional overriding.
        """
        if default_headers is not None and set_default_headers is not None:
            raise ValueError("The `default_headers` and `set_default_headers` arguments are mutually exclusive")

        if default_query is not None and set_default_query is not None:
            raise ValueError("The `default_query` and `set_default_query` arguments are mutually exclusive")

        headers = self._custom_headers
        if default_headers is not None:
            headers = {**headers, **default_headers}
        elif set_default_headers is not None:
            headers = set_default_headers

        params = self._custom_query
        if default_query is not None:
            params = {**params, **default_query}
        elif set_default_query is not None:
            params = set_default_query

        http_client = http_client or self._client
        client = self.__class__(
            api_key=api_key or self.api_key,
            account_id=account_id or self.account_id,
            base_url=base_url or self.base_url,
            timeout=self.timeout if isinstance(timeout, NotGiven) else timeout,
            http_client=http_client,
            max_retries=max_retries if is_given(max_retries) else self.max_retries,
            default_headers=headers,
            default_query=params,
            **_extra_kwargs,
        )
        client._base_url_overridden = self._base_url_overridden or base_url is not None
        return client

    # Alias for `copy` for nicer inline usage, e.g.
    # client.with_options(timeout=10).foo.create(...)
    with_options = copy

    def _get_account_id_path_param(self) -> str:
        from_client = self.account_id
        if from_client is not None:
            return from_client

        raise ValueError(
            "Missing account_id argument; Please provide it at the client level, e.g. AsyncFireworks(account_id='abcd') or per method."
        )

    @override
    def _make_status_error(
        self,
        err_msg: str,
        *,
        body: object,
        response: httpx.Response,
    ) -> APIStatusError:
        if response.status_code == 400:
            return _exceptions.BadRequestError(err_msg, response=response, body=body)

        if response.status_code == 401:
            return _exceptions.AuthenticationError(err_msg, response=response, body=body)

        if response.status_code == 403:
            return _exceptions.PermissionDeniedError(err_msg, response=response, body=body)

        if response.status_code == 404:
            return _exceptions.NotFoundError(err_msg, response=response, body=body)

        if response.status_code == 409:
            return _exceptions.ConflictError(err_msg, response=response, body=body)

        if response.status_code == 422:
            return _exceptions.UnprocessableEntityError(err_msg, response=response, body=body)

        if response.status_code == 429:
            return _exceptions.RateLimitError(err_msg, response=response, body=body)

        if response.status_code >= 500:
            return _exceptions.InternalServerError(err_msg, response=response, body=body)
        return APIStatusError(err_msg, response=response, body=body)


class FireworksWithRawResponse:
    _client: Fireworks

    def __init__(self, client: Fireworks) -> None:
        self._client = client

    @cached_property
    def chat(self) -> chat.ChatResourceWithRawResponse:
        from .resources.chat import ChatResourceWithRawResponse

        return ChatResourceWithRawResponse(self._client.chat)

    @cached_property
    def completions(self) -> completions.CompletionsResourceWithRawResponse:
        from .resources.completions import CompletionsResourceWithRawResponse

        return CompletionsResourceWithRawResponse(self._client.completions)

    @cached_property
    def batch_inference_jobs(self) -> batch_inference_jobs.BatchInferenceJobsResourceWithRawResponse:
        from .resources.batch_inference_jobs import BatchInferenceJobsResourceWithRawResponse

        return BatchInferenceJobsResourceWithRawResponse(self._client.batch_inference_jobs)

    @cached_property
    def deployments(self) -> deployments.DeploymentsResourceWithRawResponse:
        from .resources.deployments import DeploymentsResourceWithRawResponse

        return DeploymentsResourceWithRawResponse(self._client.deployments)

    @cached_property
    def models(self) -> models.ModelsResourceWithRawResponse:
        from .resources.models import ModelsResourceWithRawResponse

        return ModelsResourceWithRawResponse(self._client.models)

    @cached_property
    def lora(self) -> lora.LoraResourceWithRawResponse:
        from .resources.lora import LoraResourceWithRawResponse

        return LoraResourceWithRawResponse(self._client.lora)

    @cached_property
    def deployment_shape_versions(self) -> deployment_shape_versions.DeploymentShapeVersionsResourceWithRawResponse:
        from .resources.deployment_shape_versions import DeploymentShapeVersionsResourceWithRawResponse

        return DeploymentShapeVersionsResourceWithRawResponse(self._client.deployment_shape_versions)

    @cached_property
    def datasets(self) -> datasets.DatasetsResourceWithRawResponse:
        from .resources.datasets import DatasetsResourceWithRawResponse

        return DatasetsResourceWithRawResponse(self._client.datasets)

    @cached_property
    def supervised_fine_tuning_jobs(
        self,
    ) -> supervised_fine_tuning_jobs.SupervisedFineTuningJobsResourceWithRawResponse:
        from .resources.supervised_fine_tuning_jobs import SupervisedFineTuningJobsResourceWithRawResponse

        return SupervisedFineTuningJobsResourceWithRawResponse(self._client.supervised_fine_tuning_jobs)

    @cached_property
    def reinforcement_fine_tuning_jobs(
        self,
    ) -> reinforcement_fine_tuning_jobs.ReinforcementFineTuningJobsResourceWithRawResponse:
        from .resources.reinforcement_fine_tuning_jobs import ReinforcementFineTuningJobsResourceWithRawResponse

        return ReinforcementFineTuningJobsResourceWithRawResponse(self._client.reinforcement_fine_tuning_jobs)

    @cached_property
    def reinforcement_fine_tuning_steps(
        self,
    ) -> reinforcement_fine_tuning_steps.ReinforcementFineTuningStepsResourceWithRawResponse:
        from .resources.reinforcement_fine_tuning_steps import ReinforcementFineTuningStepsResourceWithRawResponse

        return ReinforcementFineTuningStepsResourceWithRawResponse(self._client.reinforcement_fine_tuning_steps)

    @cached_property
    def dpo_jobs(self) -> dpo_jobs.DpoJobsResourceWithRawResponse:
        from .resources.dpo_jobs import DpoJobsResourceWithRawResponse

        return DpoJobsResourceWithRawResponse(self._client.dpo_jobs)

    @cached_property
    def evaluation_jobs(self) -> evaluation_jobs.EvaluationJobsResourceWithRawResponse:
        from .resources.evaluation_jobs import EvaluationJobsResourceWithRawResponse

        return EvaluationJobsResourceWithRawResponse(self._client.evaluation_jobs)

    @cached_property
    def evaluators(self) -> evaluators.EvaluatorsResourceWithRawResponse:
        from .resources.evaluators import EvaluatorsResourceWithRawResponse

        return EvaluatorsResourceWithRawResponse(self._client.evaluators)

    @cached_property
    def accounts(self) -> accounts.AccountsResourceWithRawResponse:
        from .resources.accounts import AccountsResourceWithRawResponse

        return AccountsResourceWithRawResponse(self._client.accounts)

    @cached_property
    def users(self) -> users.UsersResourceWithRawResponse:
        from .resources.users import UsersResourceWithRawResponse

        return UsersResourceWithRawResponse(self._client.users)

    @cached_property
    def api_keys(self) -> api_keys.APIKeysResourceWithRawResponse:
        from .resources.api_keys import APIKeysResourceWithRawResponse

        return APIKeysResourceWithRawResponse(self._client.api_keys)

    @cached_property
    def secrets(self) -> secrets.SecretsResourceWithRawResponse:
        from .resources.secrets import SecretsResourceWithRawResponse

        return SecretsResourceWithRawResponse(self._client.secrets)


class AsyncFireworksWithRawResponse:
    _client: AsyncFireworks

    def __init__(self, client: AsyncFireworks) -> None:
        self._client = client

    @cached_property
    def chat(self) -> chat.AsyncChatResourceWithRawResponse:
        from .resources.chat import AsyncChatResourceWithRawResponse

        return AsyncChatResourceWithRawResponse(self._client.chat)

    @cached_property
    def completions(self) -> completions.AsyncCompletionsResourceWithRawResponse:
        from .resources.completions import AsyncCompletionsResourceWithRawResponse

        return AsyncCompletionsResourceWithRawResponse(self._client.completions)

    @cached_property
    def batch_inference_jobs(self) -> batch_inference_jobs.AsyncBatchInferenceJobsResourceWithRawResponse:
        from .resources.batch_inference_jobs import AsyncBatchInferenceJobsResourceWithRawResponse

        return AsyncBatchInferenceJobsResourceWithRawResponse(self._client.batch_inference_jobs)

    @cached_property
    def deployments(self) -> deployments.AsyncDeploymentsResourceWithRawResponse:
        from .resources.deployments import AsyncDeploymentsResourceWithRawResponse

        return AsyncDeploymentsResourceWithRawResponse(self._client.deployments)

    @cached_property
    def models(self) -> models.AsyncModelsResourceWithRawResponse:
        from .resources.models import AsyncModelsResourceWithRawResponse

        return AsyncModelsResourceWithRawResponse(self._client.models)

    @cached_property
    def lora(self) -> lora.AsyncLoraResourceWithRawResponse:
        from .resources.lora import AsyncLoraResourceWithRawResponse

        return AsyncLoraResourceWithRawResponse(self._client.lora)

    @cached_property
    def deployment_shape_versions(
        self,
    ) -> deployment_shape_versions.AsyncDeploymentShapeVersionsResourceWithRawResponse:
        from .resources.deployment_shape_versions import AsyncDeploymentShapeVersionsResourceWithRawResponse

        return AsyncDeploymentShapeVersionsResourceWithRawResponse(self._client.deployment_shape_versions)

    @cached_property
    def datasets(self) -> datasets.AsyncDatasetsResourceWithRawResponse:
        from .resources.datasets import AsyncDatasetsResourceWithRawResponse

        return AsyncDatasetsResourceWithRawResponse(self._client.datasets)

    @cached_property
    def supervised_fine_tuning_jobs(
        self,
    ) -> supervised_fine_tuning_jobs.AsyncSupervisedFineTuningJobsResourceWithRawResponse:
        from .resources.supervised_fine_tuning_jobs import AsyncSupervisedFineTuningJobsResourceWithRawResponse

        return AsyncSupervisedFineTuningJobsResourceWithRawResponse(self._client.supervised_fine_tuning_jobs)

    @cached_property
    def reinforcement_fine_tuning_jobs(
        self,
    ) -> reinforcement_fine_tuning_jobs.AsyncReinforcementFineTuningJobsResourceWithRawResponse:
        from .resources.reinforcement_fine_tuning_jobs import AsyncReinforcementFineTuningJobsResourceWithRawResponse

        return AsyncReinforcementFineTuningJobsResourceWithRawResponse(self._client.reinforcement_fine_tuning_jobs)

    @cached_property
    def reinforcement_fine_tuning_steps(
        self,
    ) -> reinforcement_fine_tuning_steps.AsyncReinforcementFineTuningStepsResourceWithRawResponse:
        from .resources.reinforcement_fine_tuning_steps import AsyncReinforcementFineTuningStepsResourceWithRawResponse

        return AsyncReinforcementFineTuningStepsResourceWithRawResponse(self._client.reinforcement_fine_tuning_steps)

    @cached_property
    def dpo_jobs(self) -> dpo_jobs.AsyncDpoJobsResourceWithRawResponse:
        from .resources.dpo_jobs import AsyncDpoJobsResourceWithRawResponse

        return AsyncDpoJobsResourceWithRawResponse(self._client.dpo_jobs)

    @cached_property
    def evaluation_jobs(self) -> evaluation_jobs.AsyncEvaluationJobsResourceWithRawResponse:
        from .resources.evaluation_jobs import AsyncEvaluationJobsResourceWithRawResponse

        return AsyncEvaluationJobsResourceWithRawResponse(self._client.evaluation_jobs)

    @cached_property
    def evaluators(self) -> evaluators.AsyncEvaluatorsResourceWithRawResponse:
        from .resources.evaluators import AsyncEvaluatorsResourceWithRawResponse

        return AsyncEvaluatorsResourceWithRawResponse(self._client.evaluators)

    @cached_property
    def accounts(self) -> accounts.AsyncAccountsResourceWithRawResponse:
        from .resources.accounts import AsyncAccountsResourceWithRawResponse

        return AsyncAccountsResourceWithRawResponse(self._client.accounts)

    @cached_property
    def users(self) -> users.AsyncUsersResourceWithRawResponse:
        from .resources.users import AsyncUsersResourceWithRawResponse

        return AsyncUsersResourceWithRawResponse(self._client.users)

    @cached_property
    def api_keys(self) -> api_keys.AsyncAPIKeysResourceWithRawResponse:
        from .resources.api_keys import AsyncAPIKeysResourceWithRawResponse

        return AsyncAPIKeysResourceWithRawResponse(self._client.api_keys)

    @cached_property
    def secrets(self) -> secrets.AsyncSecretsResourceWithRawResponse:
        from .resources.secrets import AsyncSecretsResourceWithRawResponse

        return AsyncSecretsResourceWithRawResponse(self._client.secrets)


class FireworksWithStreamedResponse:
    _client: Fireworks

    def __init__(self, client: Fireworks) -> None:
        self._client = client

    @cached_property
    def chat(self) -> chat.ChatResourceWithStreamingResponse:
        from .resources.chat import ChatResourceWithStreamingResponse

        return ChatResourceWithStreamingResponse(self._client.chat)

    @cached_property
    def completions(self) -> completions.CompletionsResourceWithStreamingResponse:
        from .resources.completions import CompletionsResourceWithStreamingResponse

        return CompletionsResourceWithStreamingResponse(self._client.completions)

    @cached_property
    def batch_inference_jobs(self) -> batch_inference_jobs.BatchInferenceJobsResourceWithStreamingResponse:
        from .resources.batch_inference_jobs import BatchInferenceJobsResourceWithStreamingResponse

        return BatchInferenceJobsResourceWithStreamingResponse(self._client.batch_inference_jobs)

    @cached_property
    def deployments(self) -> deployments.DeploymentsResourceWithStreamingResponse:
        from .resources.deployments import DeploymentsResourceWithStreamingResponse

        return DeploymentsResourceWithStreamingResponse(self._client.deployments)

    @cached_property
    def models(self) -> models.ModelsResourceWithStreamingResponse:
        from .resources.models import ModelsResourceWithStreamingResponse

        return ModelsResourceWithStreamingResponse(self._client.models)

    @cached_property
    def lora(self) -> lora.LoraResourceWithStreamingResponse:
        from .resources.lora import LoraResourceWithStreamingResponse

        return LoraResourceWithStreamingResponse(self._client.lora)

    @cached_property
    def deployment_shape_versions(
        self,
    ) -> deployment_shape_versions.DeploymentShapeVersionsResourceWithStreamingResponse:
        from .resources.deployment_shape_versions import DeploymentShapeVersionsResourceWithStreamingResponse

        return DeploymentShapeVersionsResourceWithStreamingResponse(self._client.deployment_shape_versions)

    @cached_property
    def datasets(self) -> datasets.DatasetsResourceWithStreamingResponse:
        from .resources.datasets import DatasetsResourceWithStreamingResponse

        return DatasetsResourceWithStreamingResponse(self._client.datasets)

    @cached_property
    def supervised_fine_tuning_jobs(
        self,
    ) -> supervised_fine_tuning_jobs.SupervisedFineTuningJobsResourceWithStreamingResponse:
        from .resources.supervised_fine_tuning_jobs import SupervisedFineTuningJobsResourceWithStreamingResponse

        return SupervisedFineTuningJobsResourceWithStreamingResponse(self._client.supervised_fine_tuning_jobs)

    @cached_property
    def reinforcement_fine_tuning_jobs(
        self,
    ) -> reinforcement_fine_tuning_jobs.ReinforcementFineTuningJobsResourceWithStreamingResponse:
        from .resources.reinforcement_fine_tuning_jobs import ReinforcementFineTuningJobsResourceWithStreamingResponse

        return ReinforcementFineTuningJobsResourceWithStreamingResponse(self._client.reinforcement_fine_tuning_jobs)

    @cached_property
    def reinforcement_fine_tuning_steps(
        self,
    ) -> reinforcement_fine_tuning_steps.ReinforcementFineTuningStepsResourceWithStreamingResponse:
        from .resources.reinforcement_fine_tuning_steps import ReinforcementFineTuningStepsResourceWithStreamingResponse

        return ReinforcementFineTuningStepsResourceWithStreamingResponse(self._client.reinforcement_fine_tuning_steps)

    @cached_property
    def dpo_jobs(self) -> dpo_jobs.DpoJobsResourceWithStreamingResponse:
        from .resources.dpo_jobs import DpoJobsResourceWithStreamingResponse

        return DpoJobsResourceWithStreamingResponse(self._client.dpo_jobs)

    @cached_property
    def evaluation_jobs(self) -> evaluation_jobs.EvaluationJobsResourceWithStreamingResponse:
        from .resources.evaluation_jobs import EvaluationJobsResourceWithStreamingResponse

        return EvaluationJobsResourceWithStreamingResponse(self._client.evaluation_jobs)

    @cached_property
    def evaluators(self) -> evaluators.EvaluatorsResourceWithStreamingResponse:
        from .resources.evaluators import EvaluatorsResourceWithStreamingResponse

        return EvaluatorsResourceWithStreamingResponse(self._client.evaluators)

    @cached_property
    def accounts(self) -> accounts.AccountsResourceWithStreamingResponse:
        from .resources.accounts import AccountsResourceWithStreamingResponse

        return AccountsResourceWithStreamingResponse(self._client.accounts)

    @cached_property
    def users(self) -> users.UsersResourceWithStreamingResponse:
        from .resources.users import UsersResourceWithStreamingResponse

        return UsersResourceWithStreamingResponse(self._client.users)

    @cached_property
    def api_keys(self) -> api_keys.APIKeysResourceWithStreamingResponse:
        from .resources.api_keys import APIKeysResourceWithStreamingResponse

        return APIKeysResourceWithStreamingResponse(self._client.api_keys)

    @cached_property
    def secrets(self) -> secrets.SecretsResourceWithStreamingResponse:
        from .resources.secrets import SecretsResourceWithStreamingResponse

        return SecretsResourceWithStreamingResponse(self._client.secrets)


class AsyncFireworksWithStreamedResponse:
    _client: AsyncFireworks

    def __init__(self, client: AsyncFireworks) -> None:
        self._client = client

    @cached_property
    def chat(self) -> chat.AsyncChatResourceWithStreamingResponse:
        from .resources.chat import AsyncChatResourceWithStreamingResponse

        return AsyncChatResourceWithStreamingResponse(self._client.chat)

    @cached_property
    def completions(self) -> completions.AsyncCompletionsResourceWithStreamingResponse:
        from .resources.completions import AsyncCompletionsResourceWithStreamingResponse

        return AsyncCompletionsResourceWithStreamingResponse(self._client.completions)

    @cached_property
    def batch_inference_jobs(self) -> batch_inference_jobs.AsyncBatchInferenceJobsResourceWithStreamingResponse:
        from .resources.batch_inference_jobs import AsyncBatchInferenceJobsResourceWithStreamingResponse

        return AsyncBatchInferenceJobsResourceWithStreamingResponse(self._client.batch_inference_jobs)

    @cached_property
    def deployments(self) -> deployments.AsyncDeploymentsResourceWithStreamingResponse:
        from .resources.deployments import AsyncDeploymentsResourceWithStreamingResponse

        return AsyncDeploymentsResourceWithStreamingResponse(self._client.deployments)

    @cached_property
    def models(self) -> models.AsyncModelsResourceWithStreamingResponse:
        from .resources.models import AsyncModelsResourceWithStreamingResponse

        return AsyncModelsResourceWithStreamingResponse(self._client.models)

    @cached_property
    def lora(self) -> lora.AsyncLoraResourceWithStreamingResponse:
        from .resources.lora import AsyncLoraResourceWithStreamingResponse

        return AsyncLoraResourceWithStreamingResponse(self._client.lora)

    @cached_property
    def deployment_shape_versions(
        self,
    ) -> deployment_shape_versions.AsyncDeploymentShapeVersionsResourceWithStreamingResponse:
        from .resources.deployment_shape_versions import AsyncDeploymentShapeVersionsResourceWithStreamingResponse

        return AsyncDeploymentShapeVersionsResourceWithStreamingResponse(self._client.deployment_shape_versions)

    @cached_property
    def datasets(self) -> datasets.AsyncDatasetsResourceWithStreamingResponse:
        from .resources.datasets import AsyncDatasetsResourceWithStreamingResponse

        return AsyncDatasetsResourceWithStreamingResponse(self._client.datasets)

    @cached_property
    def supervised_fine_tuning_jobs(
        self,
    ) -> supervised_fine_tuning_jobs.AsyncSupervisedFineTuningJobsResourceWithStreamingResponse:
        from .resources.supervised_fine_tuning_jobs import AsyncSupervisedFineTuningJobsResourceWithStreamingResponse

        return AsyncSupervisedFineTuningJobsResourceWithStreamingResponse(self._client.supervised_fine_tuning_jobs)

    @cached_property
    def reinforcement_fine_tuning_jobs(
        self,
    ) -> reinforcement_fine_tuning_jobs.AsyncReinforcementFineTuningJobsResourceWithStreamingResponse:
        from .resources.reinforcement_fine_tuning_jobs import (
            AsyncReinforcementFineTuningJobsResourceWithStreamingResponse,
        )

        return AsyncReinforcementFineTuningJobsResourceWithStreamingResponse(
            self._client.reinforcement_fine_tuning_jobs
        )

    @cached_property
    def reinforcement_fine_tuning_steps(
        self,
    ) -> reinforcement_fine_tuning_steps.AsyncReinforcementFineTuningStepsResourceWithStreamingResponse:
        from .resources.reinforcement_fine_tuning_steps import (
            AsyncReinforcementFineTuningStepsResourceWithStreamingResponse,
        )

        return AsyncReinforcementFineTuningStepsResourceWithStreamingResponse(
            self._client.reinforcement_fine_tuning_steps
        )

    @cached_property
    def dpo_jobs(self) -> dpo_jobs.AsyncDpoJobsResourceWithStreamingResponse:
        from .resources.dpo_jobs import AsyncDpoJobsResourceWithStreamingResponse

        return AsyncDpoJobsResourceWithStreamingResponse(self._client.dpo_jobs)

    @cached_property
    def evaluation_jobs(self) -> evaluation_jobs.AsyncEvaluationJobsResourceWithStreamingResponse:
        from .resources.evaluation_jobs import AsyncEvaluationJobsResourceWithStreamingResponse

        return AsyncEvaluationJobsResourceWithStreamingResponse(self._client.evaluation_jobs)

    @cached_property
    def evaluators(self) -> evaluators.AsyncEvaluatorsResourceWithStreamingResponse:
        from .resources.evaluators import AsyncEvaluatorsResourceWithStreamingResponse

        return AsyncEvaluatorsResourceWithStreamingResponse(self._client.evaluators)

    @cached_property
    def accounts(self) -> accounts.AsyncAccountsResourceWithStreamingResponse:
        from .resources.accounts import AsyncAccountsResourceWithStreamingResponse

        return AsyncAccountsResourceWithStreamingResponse(self._client.accounts)

    @cached_property
    def users(self) -> users.AsyncUsersResourceWithStreamingResponse:
        from .resources.users import AsyncUsersResourceWithStreamingResponse

        return AsyncUsersResourceWithStreamingResponse(self._client.users)

    @cached_property
    def api_keys(self) -> api_keys.AsyncAPIKeysResourceWithStreamingResponse:
        from .resources.api_keys import AsyncAPIKeysResourceWithStreamingResponse

        return AsyncAPIKeysResourceWithStreamingResponse(self._client.api_keys)

    @cached_property
    def secrets(self) -> secrets.AsyncSecretsResourceWithStreamingResponse:
        from .resources.secrets import AsyncSecretsResourceWithStreamingResponse

        return AsyncSecretsResourceWithStreamingResponse(self._client.secrets)


Client = Fireworks

AsyncClient = AsyncFireworks



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["EvaluatorSourceParam"]


class EvaluatorSourceParam(TypedDict, total=False):
    github_repository_name: Annotated[str, PropertyInfo(alias="githubRepositoryName")]
    """Normalized GitHub repository name (e.g.

    owner/repository) when the source is GitHub.
    """

    type: Literal["TYPE_UNSPECIFIED", "TYPE_UPLOAD", "TYPE_GITHUB", "TYPE_TEMPORARY"]
    """Identifies how the evaluator source code is provided."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["AutoTuneParam"]


class AutoTuneParam(TypedDict, total=False):
    long_prompt: Annotated[bool, PropertyInfo(alias="longPrompt")]
    """If true, this deployment is optimized for long prompt lengths."""
